# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/local_service/local_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/local_service/local_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from zetasql.wasi._pb2.zetasql.parser import parse_tree_pb2 as zetasql_dot_parser_dot_parse__tree__pb2
from zetasql.wasi._pb2.zetasql.proto import function_pb2 as zetasql_dot_proto_dot_function__pb2
from zetasql.wasi._pb2.zetasql.proto import options_pb2 as zetasql_dot_proto_dot_options__pb2
from zetasql.wasi._pb2.zetasql.proto import simple_catalog_pb2 as zetasql_dot_proto_dot_simple__catalog__pb2
from zetasql.wasi._pb2.zetasql.public import formatter_options_pb2 as zetasql_dot_public_dot_formatter__options__pb2
from zetasql.wasi._pb2.zetasql.public import options_pb2 as zetasql_dot_public_dot_options__pb2
from zetasql.wasi._pb2.zetasql.public import parse_resume_location_pb2 as zetasql_dot_public_dot_parse__resume__location__pb2
from zetasql.wasi._pb2.zetasql.public import simple_table_pb2 as zetasql_dot_public_dot_simple__table__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2
from zetasql.wasi._pb2.zetasql.public import value_pb2 as zetasql_dot_public_dot_value__pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import resolved_ast_pb2 as zetasql_dot_resolved__ast_dot_resolved__ast__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)zetasql/local_service/local_service.proto\x12\x15zetasql.local_service\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/descriptor.proto\x1a\x1fzetasql/parser/parse_tree.proto\x1a\x1czetasql/proto/function.proto\x1a\x1bzetasql/proto/options.proto\x1a\"zetasql/proto/simple_catalog.proto\x1a&zetasql/public/formatter_options.proto\x1a\x1czetasql/public/options.proto\x1a*zetasql/public/parse_resume_location.proto\x1a!zetasql/public/simple_table.proto\x1a\x19zetasql/public/type.proto\x1a\x1azetasql/public/value.proto\x1a\'zetasql/resolved_ast/resolved_ast.proto\"\xb8\x02\n\x17\x44\x65scriptorPoolListProto\x12N\n\x0b\x64\x65\x66initions\x18\x01 \x03(\x0b\x32\x39.zetasql.local_service.DescriptorPoolListProto.Definition\x1a\t\n\x07\x42uiltin\x1a\xc1\x01\n\nDefinition\x12\x41\n\x13\x66ile_descriptor_set\x18\x01 \x01(\x0b\x32\".google.protobuf.FileDescriptorSetH\x00\x12\x17\n\rregistered_id\x18\x02 \x01(\x03H\x00\x12I\n\x07\x62uiltin\x18\x03 \x01(\x0b\x32\x36.zetasql.local_service.DescriptorPoolListProto.BuiltinH\x00\x42\x0c\n\ndefinition\"2\n\x14\x44\x65scriptorPoolIdList\x12\x1a\n\x0eregistered_ids\x18\x01 \x03(\x03\x42\x02\x10\x01\"\xf5\x01\n\x0ePrepareRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x06 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x33\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12\x1d\n\x15registered_catalog_id\x18\x05 \x01(\x03J\x04\x08\x03\x10\x04\"\x85\x02\n\rPreparedState\x12\x1e\n\x16prepared_expression_id\x18\x01 \x01(\x03\x12\'\n\x0boutput_type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x1a\n\x12referenced_columns\x18\x03 \x03(\t\x12\x1d\n\x15referenced_parameters\x18\x04 \x03(\t\x12\"\n\x1apositional_parameter_count\x18\x05 \x01(\x03\x12L\n\x17\x64\x65scriptor_pool_id_list\x18\x06 \x01(\x0b\x32+.zetasql.local_service.DescriptorPoolIdList\"U\n\x0fPrepareResponse\x12\x36\n\x08prepared\x18\x03 \x01(\x0b\x32$.zetasql.local_service.PreparedStateJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\x8c\x03\n\x0f\x45valuateRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x41\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x30.zetasql.local_service.EvaluateRequest.Parameter\x12@\n\x06params\x18\x03 \x03(\x0b\x32\x30.zetasql.local_service.EvaluateRequest.Parameter\x12L\n\x14\x64\x65scriptor_pool_list\x18\x07 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x1e\n\x16prepared_expression_id\x18\x05 \x01(\x03\x12.\n\x07options\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x1a\x43\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.zetasql.ValueProtoJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"z\n\x10\x45valuateResponse\x12\"\n\x05value\x18\x01 \x01(\x0b\x32\x13.zetasql.ValueProto\x12\x36\n\x08prepared\x18\x04 \x01(\x0b\x32$.zetasql.local_service.PreparedStateJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"O\n\x14\x45valuateRequestBatch\x12\x37\n\x07request\x18\x01 \x03(\x0b\x32&.zetasql.local_service.EvaluateRequest\"R\n\x15\x45valuateResponseBatch\x12\x39\n\x08response\x18\x01 \x03(\x0b\x32\'.zetasql.local_service.EvaluateResponse\"2\n\x10UnprepareRequest\x12\x1e\n\x16prepared_expression_id\x18\x01 \x01(\x03\"\xb2\x03\n\x13PrepareQueryRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x35\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProtoH\x00\x12\x1f\n\x15registered_catalog_id\x18\x05 \x01(\x03H\x00\x12S\n\rtable_content\x18\x06 \x03(\x0b\x32<.zetasql.local_service.PrepareQueryRequest.TableContentEntry\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01\x42\t\n\x07\x63\x61talog\"\xed\x01\n\x12PreparedQueryState\x12\x19\n\x11prepared_query_id\x18\x01 \x01(\x03\x12\x1d\n\x15referenced_parameters\x18\x02 \x03(\t\x12\"\n\x1apositional_parameter_count\x18\x03 \x01(\x03\x12+\n\x07\x63olumns\x18\x04 \x03(\x0b\x32\x1a.zetasql.SimpleColumnProto\x12L\n\x17\x64\x65scriptor_pool_id_list\x18\x05 \x01(\x0b\x32+.zetasql.local_service.DescriptorPoolIdList\"S\n\x14PrepareQueryResponse\x12;\n\x08prepared\x18\x01 \x01(\x0b\x32).zetasql.local_service.PreparedQueryState\"C\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.zetasql.ValueProtoJ\x04\x08\x03\x10\x04\"2\n\x15UnprepareQueryRequest\x12\x19\n\x11prepared_query_id\x18\x01 \x01(\x03\"\x83\x04\n\x14\x45valuateQueryRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x35\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProtoH\x00\x12\x1f\n\x15registered_catalog_id\x18\x05 \x01(\x03H\x00\x12\x1b\n\x11prepared_query_id\x18\x06 \x01(\x03H\x00\x12T\n\rtable_content\x18\x07 \x03(\x0b\x32=.zetasql.local_service.EvaluateQueryRequest.TableContentEntry\x12\x30\n\x06params\x18\x08 \x03(\x0b\x32 .zetasql.local_service.Parameter\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01\x42\t\n\x07\x63\x61talog\"\x8a\x01\n\x15\x45valuateQueryResponse\x12\x34\n\x07\x63ontent\x18\x01 \x01(\x0b\x32#.zetasql.local_service.TableContent\x12;\n\x08prepared\x18\x02 \x01(\x0b\x32).zetasql.local_service.PreparedQueryState\"Y\n\x19\x45valuateQueryBatchRequest\x12<\n\x07request\x18\x01 \x03(\x0b\x32+.zetasql.local_service.EvaluateQueryRequest\"\\\n\x1a\x45valuateQueryBatchResponse\x12>\n\x08response\x18\x01 \x03(\x0b\x32,.zetasql.local_service.EvaluateQueryResponse\"\xb4\x03\n\x14PrepareModifyRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x35\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProtoH\x00\x12\x1f\n\x15registered_catalog_id\x18\x05 \x01(\x03H\x00\x12T\n\rtable_content\x18\x06 \x03(\x0b\x32=.zetasql.local_service.PrepareModifyRequest.TableContentEntry\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01\x42\t\n\x07\x63\x61talog\"\xc2\x01\n\x13PreparedModifyState\x12\x1a\n\x12prepared_modify_id\x18\x01 \x01(\x03\x12\x1d\n\x15referenced_parameters\x18\x02 \x03(\t\x12\"\n\x1apositional_parameter_count\x18\x03 \x01(\x03\x12L\n\x17\x64\x65scriptor_pool_id_list\x18\x05 \x01(\x0b\x32+.zetasql.local_service.DescriptorPoolIdList\"U\n\x15PrepareModifyResponse\x12<\n\x08prepared\x18\x01 \x01(\x0b\x32*.zetasql.local_service.PreparedModifyState\"4\n\x16UnprepareModifyRequest\x12\x1a\n\x12prepared_modify_id\x18\x01 \x01(\x03\"\x86\x04\n\x15\x45valuateModifyRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x35\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProtoH\x00\x12\x1f\n\x15registered_catalog_id\x18\x05 \x01(\x03H\x00\x12\x1c\n\x12prepared_modify_id\x18\x06 \x01(\x03H\x00\x12U\n\rtable_content\x18\x07 \x03(\x0b\x32>.zetasql.local_service.EvaluateModifyRequest.TableContentEntry\x12\x30\n\x06params\x18\x08 \x03(\x0b\x32 .zetasql.local_service.Parameter\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01\x42\t\n\x07\x63\x61talog\"\x95\x03\n\x16\x45valuateModifyResponse\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.zetasql.local_service.EvaluateModifyResponse.Row\x12<\n\x08prepared\x18\x03 \x01(\x0b\x32*.zetasql.local_service.PreparedModifyState\x1a\xe4\x01\n\x03Row\x12N\n\toperation\x18\x01 \x01(\x0e\x32;.zetasql.local_service.EvaluateModifyResponse.Row.Operation\x12!\n\x04\x63\x65ll\x18\x02 \x03(\x0b\x32\x13.zetasql.ValueProto\x12,\n\x0fold_primary_key\x18\x03 \x03(\x0b\x32\x13.zetasql.ValueProto\"<\n\tOperation\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06INSERT\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x12\n\n\x06UPDATE\x10\x03\"[\n\x1a\x45valuateModifyBatchRequest\x12=\n\x07request\x18\x01 \x03(\x0b\x32,.zetasql.local_service.EvaluateModifyRequest\"^\n\x1b\x45valuateModifyBatchResponse\x12?\n\x08response\x18\x01 \x03(\x0b\x32-.zetasql.local_service.EvaluateModifyResponse\"\x80\x01\n\x15TableFromProtoRequest\x12&\n\x05proto\x18\x01 \x01(\x0b\x32\x17.zetasql.ProtoTypeProto\x12?\n\x13\x66ile_descriptor_set\x18\x02 \x01(\x0b\x32\".google.protobuf.FileDescriptorSet\"\xef\x02\n\x0e\x41nalyzeRequest\x12.\n\x07options\x18\x01 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12\x33\n\x0esimple_catalog\x18\x02 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\t \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x1d\n\x15registered_catalog_id\x18\x04 \x01(\x03\x12\x17\n\rsql_statement\x18\x05 \x01(\tH\x00\x12\x42\n\x15parse_resume_location\x18\x06 \x01(\x0b\x32!.zetasql.ParseResumeLocationProtoH\x00\x12\x18\n\x0esql_expression\x18\x08 \x01(\tH\x00\x42\x08\n\x06targetJ\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08\"\xb9\x01\n\x0f\x41nalyzeResponse\x12@\n\x12resolved_statement\x18\x01 \x01(\x0b\x32\".zetasql.AnyResolvedStatementProtoH\x00\x12<\n\x13resolved_expression\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProtoH\x00\x12\x1c\n\x14resume_byte_position\x18\x02 \x01(\x05\x42\x08\n\x06result\"\xc3\x02\n\x0f\x42uildSqlRequest\x12\x33\n\x0esimple_catalog\x18\x01 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x06 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x1d\n\x15registered_catalog_id\x18\x03 \x01(\x03\x12@\n\x12resolved_statement\x18\x04 \x01(\x0b\x32\".zetasql.AnyResolvedStatementProtoH\x00\x12<\n\x13resolved_expression\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProtoH\x00\x42\x08\n\x06targetJ\x04\x08\x02\x10\x03\"\x1f\n\x10\x42uildSqlResponse\x12\x0b\n\x03sql\x18\x01 \x01(\t\"\x84\x01\n%ExtractTableNamesFromStatementRequest\x12\x15\n\rsql_statement\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\x12\x14\n\x0c\x61llow_script\x18\x03 \x01(\x08\"\xae\x01\n&ExtractTableNamesFromStatementResponse\x12[\n\ntable_name\x18\x01 \x03(\x0b\x32G.zetasql.local_service.ExtractTableNamesFromStatementResponse.TableName\x1a\'\n\tTableName\x12\x1a\n\x12table_name_segment\x18\x01 \x03(\t\"\x9d\x01\n)ExtractTableNamesFromNextStatementRequest\x12@\n\x15parse_resume_location\x18\x01 \x02(\x0b\x32!.zetasql.ParseResumeLocationProto\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\"\xd4\x01\n*ExtractTableNamesFromNextStatementResponse\x12_\n\ntable_name\x18\x01 \x03(\x0b\x32K.zetasql.local_service.ExtractTableNamesFromNextStatementResponse.TableName\x12\x1c\n\x14resume_byte_position\x18\x02 \x01(\x05\x1a\'\n\tTableName\x12\x1a\n\x12table_name_segment\x18\x01 \x03(\t\"\x83\x01\n\x10\x46ormatSqlRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12/\n\x07options\x18\x02 \x01(\x0b\x32\x1e.zetasql.FormatterOptionsProto\x12\x31\n\x0b\x62yte_ranges\x18\x03 \x03(\x0b\x32\x1c.zetasql.FormatterRangeProto\" \n\x11\x46ormatSqlResponse\x12\x0b\n\x03sql\x18\x01 \x01(\t\"\xd3\x02\n\x16RegisterCatalogRequest\x12\x33\n\x0esimple_catalog\x18\x01 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12V\n\rtable_content\x18\x04 \x03(\x0b\x32?.zetasql.local_service.RegisterCatalogRequest.TableContentEntry\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01J\x04\x08\x02\x10\x03\"D\n\x0cTableContent\x12\x34\n\ntable_data\x18\x01 \x01(\x0b\x32 .zetasql.local_service.TableData\"h\n\tTableData\x12\x31\n\x03row\x18\x01 \x03(\x0b\x32$.zetasql.local_service.TableData.Row\x1a(\n\x03Row\x12!\n\x04\x63\x65ll\x18\x01 \x03(\x0b\x32\x13.zetasql.ValueProto\"w\n\x10RegisterResponse\x12\x15\n\rregistered_id\x18\x01 \x01(\x03\x12L\n\x17\x64\x65scriptor_pool_id_list\x18\x02 \x01(\x0b\x32+.zetasql.local_service.DescriptorPoolIdList\"*\n\x11UnregisterRequest\x12\x15\n\rregistered_id\x18\x01 \x01(\x03\"\x99\x02\n\x1bGetBuiltinFunctionsResponse\x12(\n\x08\x66unction\x18\x01 \x03(\x0b\x32\x16.zetasql.FunctionProto\x12L\n\x05types\x18\x02 \x03(\x0b\x32=.zetasql.local_service.GetBuiltinFunctionsResponse.TypesEntry\x12@\n\x15table_valued_function\x18\x03 \x03(\x0b\x32!.zetasql.TableValuedFunctionProto\x1a@\n\nTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto:\x02\x38\x01\"f\n\x16LanguageOptionsRequest\x12\x18\n\x10maximum_features\x18\x01 \x01(\x08\x12\x32\n\x10language_version\x18\x02 \x01(\x0e\x32\x18.zetasql.LanguageVersion\"\x18\n\x16\x41nalyzerOptionsRequest\"\xbb\x01\n\x0cParseRequest\x12\x17\n\rsql_statement\x18\x01 \x01(\tH\x00\x12\x42\n\x15parse_resume_location\x18\x03 \x01(\x0b\x32!.zetasql.ParseResumeLocationProtoH\x00\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\x12\x14\n\x0c\x61llow_script\x18\x04 \x01(\x08\x42\x08\n\x06target\"\xa4\x01\n\rParseResponse\x12\x39\n\x10parsed_statement\x18\x01 \x01(\x0b\x32\x1d.zetasql.AnyASTStatementProtoH\x00\x12\x30\n\rparsed_script\x18\x03 \x01(\x0b\x32\x17.zetasql.ASTScriptProtoH\x00\x12\x1c\n\x14resume_byte_position\x18\x02 \x01(\x05\x42\x08\n\x06result2\xa2\x15\n\x13ZetaSqlLocalService\x12Z\n\x07Prepare\x12%.zetasql.local_service.PrepareRequest\x1a&.zetasql.local_service.PrepareResponse\"\x00\x12]\n\x08\x45valuate\x12&.zetasql.local_service.EvaluateRequest\x1a\'.zetasql.local_service.EvaluateResponse\"\x00\x12q\n\x0e\x45valuateStream\x12+.zetasql.local_service.EvaluateRequestBatch\x1a,.zetasql.local_service.EvaluateResponseBatch\"\x00(\x01\x30\x01\x12N\n\tUnprepare\x12\'.zetasql.local_service.UnprepareRequest\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x0cPrepareQuery\x12*.zetasql.local_service.PrepareQueryRequest\x1a+.zetasql.local_service.PrepareQueryResponse\"\x00\x12X\n\x0eUnprepareQuery\x12,.zetasql.local_service.UnprepareQueryRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\rEvaluateQuery\x12+.zetasql.local_service.EvaluateQueryRequest\x1a,.zetasql.local_service.EvaluateQueryResponse\"\x00\x12\x80\x01\n\x13\x45valuateQueryStream\x12\x30.zetasql.local_service.EvaluateQueryBatchRequest\x1a\x31.zetasql.local_service.EvaluateQueryBatchResponse\"\x00(\x01\x30\x01\x12l\n\rPrepareModify\x12+.zetasql.local_service.PrepareModifyRequest\x1a,.zetasql.local_service.PrepareModifyResponse\"\x00\x12Z\n\x0fUnprepareModify\x12-.zetasql.local_service.UnprepareModifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12o\n\x0e\x45valuateModify\x12,.zetasql.local_service.EvaluateModifyRequest\x1a-.zetasql.local_service.EvaluateModifyResponse\"\x00\x12\x83\x01\n\x14\x45valuateModifyStream\x12\x31.zetasql.local_service.EvaluateModifyBatchRequest\x1a\x32.zetasql.local_service.EvaluateModifyBatchResponse\"\x00(\x01\x30\x01\x12^\n\x11GetTableFromProto\x12,.zetasql.local_service.TableFromProtoRequest\x1a\x19.zetasql.SimpleTableProto\"\x00\x12k\n\x0fRegisterCatalog\x12-.zetasql.local_service.RegisterCatalogRequest\x1a\'.zetasql.local_service.RegisterResponse\"\x00\x12Z\n\x07\x41nalyze\x12%.zetasql.local_service.AnalyzeRequest\x1a&.zetasql.local_service.AnalyzeResponse\"\x00\x12]\n\x08\x42uildSql\x12&.zetasql.local_service.BuildSqlRequest\x1a\'.zetasql.local_service.BuildSqlResponse\"\x00\x12\x9f\x01\n\x1e\x45xtractTableNamesFromStatement\x12<.zetasql.local_service.ExtractTableNamesFromStatementRequest\x1a=.zetasql.local_service.ExtractTableNamesFromStatementResponse\"\x00\x12\xab\x01\n\"ExtractTableNamesFromNextStatement\x12@.zetasql.local_service.ExtractTableNamesFromNextStatementRequest\x1a\x41.zetasql.local_service.ExtractTableNamesFromNextStatementResponse\"\x00\x12`\n\tFormatSql\x12\'.zetasql.local_service.FormatSqlRequest\x1a(.zetasql.local_service.FormatSqlResponse\"\x00\x12g\n\x10LenientFormatSql\x12\'.zetasql.local_service.FormatSqlRequest\x1a(.zetasql.local_service.FormatSqlResponse\"\x00\x12W\n\x11UnregisterCatalog\x12(.zetasql.local_service.UnregisterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12x\n\x13GetBuiltinFunctions\x12+.zetasql.ZetaSQLBuiltinFunctionOptionsProto\x1a\x32.zetasql.local_service.GetBuiltinFunctionsResponse\"\x00\x12\x64\n\x12GetLanguageOptions\x12-.zetasql.local_service.LanguageOptionsRequest\x1a\x1d.zetasql.LanguageOptionsProto\"\x00\x12\x64\n\x12GetAnalyzerOptions\x12-.zetasql.local_service.AnalyzerOptionsRequest\x1a\x1d.zetasql.AnalyzerOptionsProto\"\x00\x12T\n\x05Parse\x12#.zetasql.local_service.ParseRequest\x1a$.zetasql.local_service.ParseResponse\"\x00\x42\"\n\x12\x63om.google.zetasqlB\x0cLocalService')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.local_service.local_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\014LocalService'
  _globals['_DESCRIPTORPOOLIDLIST'].fields_by_name['registered_ids']._loaded_options = None
  _globals['_DESCRIPTORPOOLIDLIST'].fields_by_name['registered_ids']._serialized_options = b'\020\001'
  _globals['_PREPAREQUERYREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_PREPAREQUERYREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATEQUERYREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_EVALUATEQUERYREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_PREPAREMODIFYREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_PREPAREMODIFYREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATEMODIFYREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_EVALUATEMODIFYREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERCATALOGREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_REGISTERCATALOGREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_GETBUILTINFUNCTIONSRESPONSE_TYPESENTRY']._loaded_options = None
  _globals['_GETBUILTINFUNCTIONSRESPONSE_TYPESENTRY']._serialized_options = b'8\001'
  _globals['_DESCRIPTORPOOLLISTPROTO']._serialized_start=505
  _globals['_DESCRIPTORPOOLLISTPROTO']._serialized_end=817
  _globals['_DESCRIPTORPOOLLISTPROTO_BUILTIN']._serialized_start=612
  _globals['_DESCRIPTORPOOLLISTPROTO_BUILTIN']._serialized_end=621
  _globals['_DESCRIPTORPOOLLISTPROTO_DEFINITION']._serialized_start=624
  _globals['_DESCRIPTORPOOLLISTPROTO_DEFINITION']._serialized_end=817
  _globals['_DESCRIPTORPOOLIDLIST']._serialized_start=819
  _globals['_DESCRIPTORPOOLIDLIST']._serialized_end=869
  _globals['_PREPAREREQUEST']._serialized_start=872
  _globals['_PREPAREREQUEST']._serialized_end=1117
  _globals['_PREPAREDSTATE']._serialized_start=1120
  _globals['_PREPAREDSTATE']._serialized_end=1381
  _globals['_PREPARERESPONSE']._serialized_start=1383
  _globals['_PREPARERESPONSE']._serialized_end=1468
  _globals['_EVALUATEREQUEST']._serialized_start=1471
  _globals['_EVALUATEREQUEST']._serialized_end=1867
  _globals['_EVALUATEREQUEST_PARAMETER']._serialized_start=1794
  _globals['_EVALUATEREQUEST_PARAMETER']._serialized_end=1861
  _globals['_EVALUATERESPONSE']._serialized_start=1869
  _globals['_EVALUATERESPONSE']._serialized_end=1991
  _globals['_EVALUATEREQUESTBATCH']._serialized_start=1993
  _globals['_EVALUATEREQUESTBATCH']._serialized_end=2072
  _globals['_EVALUATERESPONSEBATCH']._serialized_start=2074
  _globals['_EVALUATERESPONSEBATCH']._serialized_end=2156
  _globals['_UNPREPAREREQUEST']._serialized_start=2158
  _globals['_UNPREPAREREQUEST']._serialized_end=2208
  _globals['_PREPAREQUERYREQUEST']._serialized_start=2211
  _globals['_PREPAREQUERYREQUEST']._serialized_end=2645
  _globals['_PREPAREQUERYREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_PREPAREQUERYREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_PREPAREDQUERYSTATE']._serialized_start=2648
  _globals['_PREPAREDQUERYSTATE']._serialized_end=2885
  _globals['_PREPAREQUERYRESPONSE']._serialized_start=2887
  _globals['_PREPAREQUERYRESPONSE']._serialized_end=2970
  _globals['_PARAMETER']._serialized_start=1794
  _globals['_PARAMETER']._serialized_end=1861
  _globals['_UNPREPAREQUERYREQUEST']._serialized_start=3041
  _globals['_UNPREPAREQUERYREQUEST']._serialized_end=3091
  _globals['_EVALUATEQUERYREQUEST']._serialized_start=3094
  _globals['_EVALUATEQUERYREQUEST']._serialized_end=3609
  _globals['_EVALUATEQUERYREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_EVALUATEQUERYREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_EVALUATEQUERYRESPONSE']._serialized_start=3612
  _globals['_EVALUATEQUERYRESPONSE']._serialized_end=3750
  _globals['_EVALUATEQUERYBATCHREQUEST']._serialized_start=3752
  _globals['_EVALUATEQUERYBATCHREQUEST']._serialized_end=3841
  _globals['_EVALUATEQUERYBATCHRESPONSE']._serialized_start=3843
  _globals['_EVALUATEQUERYBATCHRESPONSE']._serialized_end=3935
  _globals['_PREPAREMODIFYREQUEST']._serialized_start=3938
  _globals['_PREPAREMODIFYREQUEST']._serialized_end=4374
  _globals['_PREPAREMODIFYREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_PREPAREMODIFYREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_PREPAREDMODIFYSTATE']._serialized_start=4377
  _globals['_PREPAREDMODIFYSTATE']._serialized_end=4571
  _globals['_PREPAREMODIFYRESPONSE']._serialized_start=4573
  _globals['_PREPAREMODIFYRESPONSE']._serialized_end=4658
  _globals['_UNPREPAREMODIFYREQUEST']._serialized_start=4660
  _globals['_UNPREPAREMODIFYREQUEST']._serialized_end=4712
  _globals['_EVALUATEMODIFYREQUEST']._serialized_start=4715
  _globals['_EVALUATEMODIFYREQUEST']._serialized_end=5233
  _globals['_EVALUATEMODIFYREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_EVALUATEMODIFYREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_EVALUATEMODIFYRESPONSE']._serialized_start=5236
  _globals['_EVALUATEMODIFYRESPONSE']._serialized_end=5641
  _globals['_EVALUATEMODIFYRESPONSE_ROW']._serialized_start=5413
  _globals['_EVALUATEMODIFYRESPONSE_ROW']._serialized_end=5641
  _globals['_EVALUATEMODIFYRESPONSE_ROW_OPERATION']._serialized_start=5581
  _globals['_EVALUATEMODIFYRESPONSE_ROW_OPERATION']._serialized_end=5641
  _globals['_EVALUATEMODIFYBATCHREQUEST']._serialized_start=5643
  _globals['_EVALUATEMODIFYBATCHREQUEST']._serialized_end=5734
  _globals['_EVALUATEMODIFYBATCHRESPONSE']._serialized_start=5736
  _globals['_EVALUATEMODIFYBATCHRESPONSE']._serialized_end=5830
  _globals['_TABLEFROMPROTOREQUEST']._serialized_start=5833
  _globals['_TABLEFROMPROTOREQUEST']._serialized_end=5961
  _globals['_ANALYZEREQUEST']._serialized_start=5964
  _globals['_ANALYZEREQUEST']._serialized_end=6331
  _globals['_ANALYZERESPONSE']._serialized_start=6334
  _globals['_ANALYZERESPONSE']._serialized_end=6519
  _globals['_BUILDSQLREQUEST']._serialized_start=6522
  _globals['_BUILDSQLREQUEST']._serialized_end=6845
  _globals['_BUILDSQLRESPONSE']._serialized_start=6847
  _globals['_BUILDSQLRESPONSE']._serialized_end=6878
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTREQUEST']._serialized_start=6881
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTREQUEST']._serialized_end=7013
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTRESPONSE']._serialized_start=7016
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTRESPONSE']._serialized_end=7190
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTRESPONSE_TABLENAME']._serialized_start=7151
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTRESPONSE_TABLENAME']._serialized_end=7190
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTREQUEST']._serialized_start=7193
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTREQUEST']._serialized_end=7350
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTRESPONSE']._serialized_start=7353
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTRESPONSE']._serialized_end=7565
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTRESPONSE_TABLENAME']._serialized_start=7151
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTRESPONSE_TABLENAME']._serialized_end=7190
  _globals['_FORMATSQLREQUEST']._serialized_start=7568
  _globals['_FORMATSQLREQUEST']._serialized_end=7699
  _globals['_FORMATSQLRESPONSE']._serialized_start=7701
  _globals['_FORMATSQLRESPONSE']._serialized_end=7733
  _globals['_REGISTERCATALOGREQUEST']._serialized_start=7736
  _globals['_REGISTERCATALOGREQUEST']._serialized_end=8075
  _globals['_REGISTERCATALOGREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_REGISTERCATALOGREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_TABLECONTENT']._serialized_start=8077
  _globals['_TABLECONTENT']._serialized_end=8145
  _globals['_TABLEDATA']._serialized_start=8147
  _globals['_TABLEDATA']._serialized_end=8251
  _globals['_TABLEDATA_ROW']._serialized_start=8211
  _globals['_TABLEDATA_ROW']._serialized_end=8251
  _globals['_REGISTERRESPONSE']._serialized_start=8253
  _globals['_REGISTERRESPONSE']._serialized_end=8372
  _globals['_UNREGISTERREQUEST']._serialized_start=8374
  _globals['_UNREGISTERREQUEST']._serialized_end=8416
  _globals['_GETBUILTINFUNCTIONSRESPONSE']._serialized_start=8419
  _globals['_GETBUILTINFUNCTIONSRESPONSE']._serialized_end=8700
  _globals['_GETBUILTINFUNCTIONSRESPONSE_TYPESENTRY']._serialized_start=8636
  _globals['_GETBUILTINFUNCTIONSRESPONSE_TYPESENTRY']._serialized_end=8700
  _globals['_LANGUAGEOPTIONSREQUEST']._serialized_start=8702
  _globals['_LANGUAGEOPTIONSREQUEST']._serialized_end=8804
  _globals['_ANALYZEROPTIONSREQUEST']._serialized_start=8806
  _globals['_ANALYZEROPTIONSREQUEST']._serialized_end=8830
  _globals['_PARSEREQUEST']._serialized_start=8833
  _globals['_PARSEREQUEST']._serialized_end=9020
  _globals['_PARSERESPONSE']._serialized_start=9023
  _globals['_PARSERESPONSE']._serialized_end=9187
  _globals['_ZETASQLLOCALSERVICE']._serialized_start=9190
  _globals['_ZETASQLLOCALSERVICE']._serialized_end=11912
# @@protoc_insertion_point(module_scope)



"""
ZetaSQL - Python port of Google's ZetaSQL

This is a Python implementation of ZetaSQL, providing SQL analysis and parsing
capabilities for Python applications.

Architecture:
    The library is organized into 3 layers:

    - wasi: Layer 0 - WebAssembly resources and generated protobuf code
    - core: Layer 1 - WASI communication & ProtoModel infrastructure
    - api: Layer 2 - Convenience features
    - types: exported types

Recommended Usage:
    Use explicit import paths for clarity:

    from zetasql.core import ZetaSqlLocalService
    from zetasql.api import Analyzer, PreparedQuery, CatalogBuilder, TableBuilder, create_table_content
    from zetasql.types import TypeKind, AnalyzerOptions, proto_models
"""

from zetasql.__version__ import __version__

__all__ = [
    "__version__",
]



from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from zetasql.wasi._pb2.zetasql.parser import parse_tree_pb2 as _parse_tree_pb2
from zetasql.wasi._pb2.zetasql.proto import function_pb2 as _function_pb2
from zetasql.wasi._pb2.zetasql.proto import options_pb2 as _options_pb2
from zetasql.wasi._pb2.zetasql.proto import simple_catalog_pb2 as _simple_catalog_pb2
from zetasql.wasi._pb2.zetasql.public import formatter_options_pb2 as _formatter_options_pb2
from zetasql.wasi._pb2.zetasql.public import options_pb2 as _options_pb2_1
from zetasql.wasi._pb2.zetasql.public import parse_resume_location_pb2 as _parse_resume_location_pb2
from zetasql.wasi._pb2.zetasql.public import simple_table_pb2 as _simple_table_pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from zetasql.wasi._pb2.zetasql.public import value_pb2 as _value_pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import resolved_ast_pb2 as _resolved_ast_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescriptorPoolListProto(_message.Message):
    __slots__ = ("definitions",)
    class Builtin(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Definition(_message.Message):
        __slots__ = ("file_descriptor_set", "registered_id", "builtin")
        FILE_DESCRIPTOR_SET_FIELD_NUMBER: _ClassVar[int]
        REGISTERED_ID_FIELD_NUMBER: _ClassVar[int]
        BUILTIN_FIELD_NUMBER: _ClassVar[int]
        file_descriptor_set: _descriptor_pb2.FileDescriptorSet
        registered_id: int
        builtin: DescriptorPoolListProto.Builtin
        def __init__(self, file_descriptor_set: _Optional[_Union[_descriptor_pb2.FileDescriptorSet, _Mapping]] = ..., registered_id: _Optional[int] = ..., builtin: _Optional[_Union[DescriptorPoolListProto.Builtin, _Mapping]] = ...) -> None: ...
    DEFINITIONS_FIELD_NUMBER: _ClassVar[int]
    definitions: _containers.RepeatedCompositeFieldContainer[DescriptorPoolListProto.Definition]
    def __init__(self, definitions: _Optional[_Iterable[_Union[DescriptorPoolListProto.Definition, _Mapping]]] = ...) -> None: ...

class DescriptorPoolIdList(_message.Message):
    __slots__ = ("registered_ids",)
    REGISTERED_IDS_FIELD_NUMBER: _ClassVar[int]
    registered_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, registered_ids: _Optional[_Iterable[int]] = ...) -> None: ...

class PrepareRequest(_message.Message):
    __slots__ = ("sql", "options", "descriptor_pool_list", "simple_catalog", "registered_catalog_id")
    SQL_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_CATALOG_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    sql: str
    options: _options_pb2.AnalyzerOptionsProto
    descriptor_pool_list: DescriptorPoolListProto
    simple_catalog: _simple_catalog_pb2.SimpleCatalogProto
    registered_catalog_id: int
    def __init__(self, sql: _Optional[str] = ..., options: _Optional[_Union[_options_pb2.AnalyzerOptionsProto, _Mapping]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., simple_catalog: _Optional[_Union[_simple_catalog_pb2.SimpleCatalogProto, _Mapping]] = ..., registered_catalog_id: _Optional[int] = ...) -> None: ...

class PreparedState(_message.Message):
    __slots__ = ("prepared_expression_id", "output_type", "referenced_columns", "referenced_parameters", "positional_parameter_count", "descriptor_pool_id_list")
    PREPARED_EXPRESSION_ID_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TYPE_FIELD_NUMBER: _ClassVar[int]
    REFERENCED_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    REFERENCED_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    POSITIONAL_PARAMETER_COUNT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_ID_LIST_FIELD_NUMBER: _ClassVar[int]
    prepared_expression_id: int
    output_type: _type_pb2.TypeProto
    referenced_columns: _containers.RepeatedScalarFieldContainer[str]
    referenced_parameters: _containers.RepeatedScalarFieldContainer[str]
    positional_parameter_count: int
    descriptor_pool_id_list: DescriptorPoolIdList
    def __init__(self, prepared_expression_id: _Optional[int] = ..., output_type: _Optional[_Union[_type_pb2.TypeProto, _Mapping]] = ..., referenced_columns: _Optional[_Iterable[str]] = ..., referenced_parameters: _Optional[_Iterable[str]] = ..., positional_parameter_count: _Optional[int] = ..., descriptor_pool_id_list: _Optional[_Union[DescriptorPoolIdList, _Mapping]] = ...) -> None: ...

class PrepareResponse(_message.Message):
    __slots__ = ("prepared",)
    PREPARED_FIELD_NUMBER: _ClassVar[int]
    prepared: PreparedState
    def __init__(self, prepared: _Optional[_Union[PreparedState, _Mapping]] = ...) -> None: ...

class EvaluateRequest(_message.Message):
    __slots__ = ("sql", "columns", "params", "descriptor_pool_list", "prepared_expression_id", "options")
    class Parameter(_message.Message):
        __slots__ = ("name", "value")
        NAME_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        name: str
        value: _value_pb2.ValueProto
        def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[_value_pb2.ValueProto, _Mapping]] = ...) -> None: ...
    SQL_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    PREPARED_EXPRESSION_ID_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    sql: str
    columns: _containers.RepeatedCompositeFieldContainer[EvaluateRequest.Parameter]
    params: _containers.RepeatedCompositeFieldContainer[EvaluateRequest.Parameter]
    descriptor_pool_list: DescriptorPoolListProto
    prepared_expression_id: int
    options: _options_pb2.AnalyzerOptionsProto
    def __init__(self, sql: _Optional[str] = ..., columns: _Optional[_Iterable[_Union[EvaluateRequest.Parameter, _Mapping]]] = ..., params: _Optional[_Iterable[_Union[EvaluateRequest.Parameter, _Mapping]]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., prepared_expression_id: _Optional[int] = ..., options: _Optional[_Union[_options_pb2.AnalyzerOptionsProto, _Mapping]] = ...) -> None: ...

class EvaluateResponse(_message.Message):
    __slots__ = ("value", "prepared")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    PREPARED_FIELD_NUMBER: _ClassVar[int]
    value: _value_pb2.ValueProto
    prepared: PreparedState
    def __init__(self, value: _Optional[_Union[_value_pb2.ValueProto, _Mapping]] = ..., prepared: _Optional[_Union[PreparedState, _Mapping]] = ...) -> None: ...

class EvaluateRequestBatch(_message.Message):
    __slots__ = ("request",)
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    request: _containers.RepeatedCompositeFieldContainer[EvaluateRequest]
    def __init__(self, request: _Optional[_Iterable[_Union[EvaluateRequest, _Mapping]]] = ...) -> None: ...

class EvaluateResponseBatch(_message.Message):
    __slots__ = ("response",)
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    response: _containers.RepeatedCompositeFieldContainer[EvaluateResponse]
    def __init__(self, response: _Optional[_Iterable[_Union[EvaluateResponse, _Mapping]]] = ...) -> None: ...

class UnprepareRequest(_message.Message):
    __slots__ = ("prepared_expression_id",)
    PREPARED_EXPRESSION_ID_FIELD_NUMBER: _ClassVar[int]
    prepared_expression_id: int
    def __init__(self, prepared_expression_id: _Optional[int] = ...) -> None: ...

class PrepareQueryRequest(_message.Message):
    __slots__ = ("sql", "options", "descriptor_pool_list", "simple_catalog", "registered_catalog_id", "table_content")
    class TableContentEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: TableContent
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[TableContent, _Mapping]] = ...) -> None: ...
    SQL_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_CATALOG_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_CONTENT_FIELD_NUMBER: _ClassVar[int]
    sql: str
    options: _options_pb2.AnalyzerOptionsProto
    descriptor_pool_list: DescriptorPoolListProto
    simple_catalog: _simple_catalog_pb2.SimpleCatalogProto
    registered_catalog_id: int
    table_content: _containers.MessageMap[str, TableContent]
    def __init__(self, sql: _Optional[str] = ..., options: _Optional[_Union[_options_pb2.AnalyzerOptionsProto, _Mapping]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., simple_catalog: _Optional[_Union[_simple_catalog_pb2.SimpleCatalogProto, _Mapping]] = ..., registered_catalog_id: _Optional[int] = ..., table_content: _Optional[_Mapping[str, TableContent]] = ...) -> None: ...

class PreparedQueryState(_message.Message):
    __slots__ = ("prepared_query_id", "referenced_parameters", "positional_parameter_count", "columns", "descriptor_pool_id_list")
    PREPARED_QUERY_ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCED_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    POSITIONAL_PARAMETER_COUNT_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_ID_LIST_FIELD_NUMBER: _ClassVar[int]
    prepared_query_id: int
    referenced_parameters: _containers.RepeatedScalarFieldContainer[str]
    positional_parameter_count: int
    columns: _containers.RepeatedCompositeFieldContainer[_simple_table_pb2.SimpleColumnProto]
    descriptor_pool_id_list: DescriptorPoolIdList
    def __init__(self, prepared_query_id: _Optional[int] = ..., referenced_parameters: _Optional[_Iterable[str]] = ..., positional_parameter_count: _Optional[int] = ..., columns: _Optional[_Iterable[_Union[_simple_table_pb2.SimpleColumnProto, _Mapping]]] = ..., descriptor_pool_id_list: _Optional[_Union[DescriptorPoolIdList, _Mapping]] = ...) -> None: ...

class PrepareQueryResponse(_message.Message):
    __slots__ = ("prepared",)
    PREPARED_FIELD_NUMBER: _ClassVar[int]
    prepared: PreparedQueryState
    def __init__(self, prepared: _Optional[_Union[PreparedQueryState, _Mapping]] = ...) -> None: ...

class Parameter(_message.Message):
    __slots__ = ("name", "value")
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: _value_pb2.ValueProto
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[_value_pb2.ValueProto, _Mapping]] = ...) -> None: ...

class UnprepareQueryRequest(_message.Message):
    __slots__ = ("prepared_query_id",)
    PREPARED_QUERY_ID_FIELD_NUMBER: _ClassVar[int]
    prepared_query_id: int
    def __init__(self, prepared_query_id: _Optional[int] = ...) -> None: ...

class EvaluateQueryRequest(_message.Message):
    __slots__ = ("sql", "options", "descriptor_pool_list", "simple_catalog", "registered_catalog_id", "prepared_query_id", "table_content", "params")
    class TableContentEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: TableContent
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[TableContent, _Mapping]] = ...) -> None: ...
    SQL_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_CATALOG_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    PREPARED_QUERY_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_CONTENT_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    sql: str
    options: _options_pb2.AnalyzerOptionsProto
    descriptor_pool_list: DescriptorPoolListProto
    simple_catalog: _simple_catalog_pb2.SimpleCatalogProto
    registered_catalog_id: int
    prepared_query_id: int
    table_content: _containers.MessageMap[str, TableContent]
    params: _containers.RepeatedCompositeFieldContainer[Parameter]
    def __init__(self, sql: _Optional[str] = ..., options: _Optional[_Union[_options_pb2.AnalyzerOptionsProto, _Mapping]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., simple_catalog: _Optional[_Union[_simple_catalog_pb2.SimpleCatalogProto, _Mapping]] = ..., registered_catalog_id: _Optional[int] = ..., prepared_query_id: _Optional[int] = ..., table_content: _Optional[_Mapping[str, TableContent]] = ..., params: _Optional[_Iterable[_Union[Parameter, _Mapping]]] = ...) -> None: ...

class EvaluateQueryResponse(_message.Message):
    __slots__ = ("content", "prepared")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    PREPARED_FIELD_NUMBER: _ClassVar[int]
    content: TableContent
    prepared: PreparedQueryState
    def __init__(self, content: _Optional[_Union[TableContent, _Mapping]] = ..., prepared: _Optional[_Union[PreparedQueryState, _Mapping]] = ...) -> None: ...

class EvaluateQueryBatchRequest(_message.Message):
    __slots__ = ("request",)
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    request: _containers.RepeatedCompositeFieldContainer[EvaluateQueryRequest]
    def __init__(self, request: _Optional[_Iterable[_Union[EvaluateQueryRequest, _Mapping]]] = ...) -> None: ...

class EvaluateQueryBatchResponse(_message.Message):
    __slots__ = ("response",)
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    response: _containers.RepeatedCompositeFieldContainer[EvaluateQueryResponse]
    def __init__(self, response: _Optional[_Iterable[_Union[EvaluateQueryResponse, _Mapping]]] = ...) -> None: ...

class PrepareModifyRequest(_message.Message):
    __slots__ = ("sql", "options", "descriptor_pool_list", "simple_catalog", "registered_catalog_id", "table_content")
    class TableContentEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: TableContent
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[TableContent, _Mapping]] = ...) -> None: ...
    SQL_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_CATALOG_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_CONTENT_FIELD_NUMBER: _ClassVar[int]
    sql: str
    options: _options_pb2.AnalyzerOptionsProto
    descriptor_pool_list: DescriptorPoolListProto
    simple_catalog: _simple_catalog_pb2.SimpleCatalogProto
    registered_catalog_id: int
    table_content: _containers.MessageMap[str, TableContent]
    def __init__(self, sql: _Optional[str] = ..., options: _Optional[_Union[_options_pb2.AnalyzerOptionsProto, _Mapping]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., simple_catalog: _Optional[_Union[_simple_catalog_pb2.SimpleCatalogProto, _Mapping]] = ..., registered_catalog_id: _Optional[int] = ..., table_content: _Optional[_Mapping[str, TableContent]] = ...) -> None: ...

class PreparedModifyState(_message.Message):
    __slots__ = ("prepared_modify_id", "referenced_parameters", "positional_parameter_count", "descriptor_pool_id_list")
    PREPARED_MODIFY_ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCED_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    POSITIONAL_PARAMETER_COUNT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_ID_LIST_FIELD_NUMBER: _ClassVar[int]
    prepared_modify_id: int
    referenced_parameters: _containers.RepeatedScalarFieldContainer[str]
    positional_parameter_count: int
    descriptor_pool_id_list: DescriptorPoolIdList
    def __init__(self, prepared_modify_id: _Optional[int] = ..., referenced_parameters: _Optional[_Iterable[str]] = ..., positional_parameter_count: _Optional[int] = ..., descriptor_pool_id_list: _Optional[_Union[DescriptorPoolIdList, _Mapping]] = ...) -> None: ...

class PrepareModifyResponse(_message.Message):
    __slots__ = ("prepared",)
    PREPARED_FIELD_NUMBER: _ClassVar[int]
    prepared: PreparedModifyState
    def __init__(self, prepared: _Optional[_Union[PreparedModifyState, _Mapping]] = ...) -> None: ...

class UnprepareModifyRequest(_message.Message):
    __slots__ = ("prepared_modify_id",)
    PREPARED_MODIFY_ID_FIELD_NUMBER: _ClassVar[int]
    prepared_modify_id: int
    def __init__(self, prepared_modify_id: _Optional[int] = ...) -> None: ...

class EvaluateModifyRequest(_message.Message):
    __slots__ = ("sql", "options", "descriptor_pool_list", "simple_catalog", "registered_catalog_id", "prepared_modify_id", "table_content", "params")
    class TableContentEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: TableContent
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[TableContent, _Mapping]] = ...) -> None: ...
    SQL_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_CATALOG_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    PREPARED_MODIFY_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_CONTENT_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    sql: str
    options: _options_pb2.AnalyzerOptionsProto
    descriptor_pool_list: DescriptorPoolListProto
    simple_catalog: _simple_catalog_pb2.SimpleCatalogProto
    registered_catalog_id: int
    prepared_modify_id: int
    table_content: _containers.MessageMap[str, TableContent]
    params: _containers.RepeatedCompositeFieldContainer[Parameter]
    def __init__(self, sql: _Optional[str] = ..., options: _Optional[_Union[_options_pb2.AnalyzerOptionsProto, _Mapping]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., simple_catalog: _Optional[_Union[_simple_catalog_pb2.SimpleCatalogProto, _Mapping]] = ..., registered_catalog_id: _Optional[int] = ..., prepared_modify_id: _Optional[int] = ..., table_content: _Optional[_Mapping[str, TableContent]] = ..., params: _Optional[_Iterable[_Union[Parameter, _Mapping]]] = ...) -> None: ...

class EvaluateModifyResponse(_message.Message):
    __slots__ = ("table_name", "content", "prepared")
    class Row(_message.Message):
        __slots__ = ("operation", "cell", "old_primary_key")
        class Operation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN: _ClassVar[EvaluateModifyResponse.Row.Operation]
            INSERT: _ClassVar[EvaluateModifyResponse.Row.Operation]
            DELETE: _ClassVar[EvaluateModifyResponse.Row.Operation]
            UPDATE: _ClassVar[EvaluateModifyResponse.Row.Operation]
        UNKNOWN: EvaluateModifyResponse.Row.Operation
        INSERT: EvaluateModifyResponse.Row.Operation
        DELETE: EvaluateModifyResponse.Row.Operation
        UPDATE: EvaluateModifyResponse.Row.Operation
        OPERATION_FIELD_NUMBER: _ClassVar[int]
        CELL_FIELD_NUMBER: _ClassVar[int]
        OLD_PRIMARY_KEY_FIELD_NUMBER: _ClassVar[int]
        operation: EvaluateModifyResponse.Row.Operation
        cell: _containers.RepeatedCompositeFieldContainer[_value_pb2.ValueProto]
        old_primary_key: _containers.RepeatedCompositeFieldContainer[_value_pb2.ValueProto]
        def __init__(self, operation: _Optional[_Union[EvaluateModifyResponse.Row.Operation, str]] = ..., cell: _Optional[_Iterable[_Union[_value_pb2.ValueProto, _Mapping]]] = ..., old_primary_key: _Optional[_Iterable[_Union[_value_pb2.ValueProto, _Mapping]]] = ...) -> None: ...
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    PREPARED_FIELD_NUMBER: _ClassVar[int]
    table_name: str
    content: _containers.RepeatedCompositeFieldContainer[EvaluateModifyResponse.Row]
    prepared: PreparedModifyState
    def __init__(self, table_name: _Optional[str] = ..., content: _Optional[_Iterable[_Union[EvaluateModifyResponse.Row, _Mapping]]] = ..., prepared: _Optional[_Union[PreparedModifyState, _Mapping]] = ...) -> None: ...

class EvaluateModifyBatchRequest(_message.Message):
    __slots__ = ("request",)
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    request: _containers.RepeatedCompositeFieldContainer[EvaluateModifyRequest]
    def __init__(self, request: _Optional[_Iterable[_Union[EvaluateModifyRequest, _Mapping]]] = ...) -> None: ...

class EvaluateModifyBatchResponse(_message.Message):
    __slots__ = ("response",)
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    response: _containers.RepeatedCompositeFieldContainer[EvaluateModifyResponse]
    def __init__(self, response: _Optional[_Iterable[_Union[EvaluateModifyResponse, _Mapping]]] = ...) -> None: ...

class TableFromProtoRequest(_message.Message):
    __slots__ = ("proto", "file_descriptor_set")
    PROTO_FIELD_NUMBER: _ClassVar[int]
    FILE_DESCRIPTOR_SET_FIELD_NUMBER: _ClassVar[int]
    proto: _type_pb2.ProtoTypeProto
    file_descriptor_set: _descriptor_pb2.FileDescriptorSet
    def __init__(self, proto: _Optional[_Union[_type_pb2.ProtoTypeProto, _Mapping]] = ..., file_descriptor_set: _Optional[_Union[_descriptor_pb2.FileDescriptorSet, _Mapping]] = ...) -> None: ...

class AnalyzeRequest(_message.Message):
    __slots__ = ("options", "simple_catalog", "descriptor_pool_list", "registered_catalog_id", "sql_statement", "parse_resume_location", "sql_expression")
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_CATALOG_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    SQL_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    PARSE_RESUME_LOCATION_FIELD_NUMBER: _ClassVar[int]
    SQL_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    options: _options_pb2.AnalyzerOptionsProto
    simple_catalog: _simple_catalog_pb2.SimpleCatalogProto
    descriptor_pool_list: DescriptorPoolListProto
    registered_catalog_id: int
    sql_statement: str
    parse_resume_location: _parse_resume_location_pb2.ParseResumeLocationProto
    sql_expression: str
    def __init__(self, options: _Optional[_Union[_options_pb2.AnalyzerOptionsProto, _Mapping]] = ..., simple_catalog: _Optional[_Union[_simple_catalog_pb2.SimpleCatalogProto, _Mapping]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., registered_catalog_id: _Optional[int] = ..., sql_statement: _Optional[str] = ..., parse_resume_location: _Optional[_Union[_parse_resume_location_pb2.ParseResumeLocationProto, _Mapping]] = ..., sql_expression: _Optional[str] = ...) -> None: ...

class AnalyzeResponse(_message.Message):
    __slots__ = ("resolved_statement", "resolved_expression", "resume_byte_position")
    RESOLVED_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    RESUME_BYTE_POSITION_FIELD_NUMBER: _ClassVar[int]
    resolved_statement: _resolved_ast_pb2.AnyResolvedStatementProto
    resolved_expression: _resolved_ast_pb2.AnyResolvedExprProto
    resume_byte_position: int
    def __init__(self, resolved_statement: _Optional[_Union[_resolved_ast_pb2.AnyResolvedStatementProto, _Mapping]] = ..., resolved_expression: _Optional[_Union[_resolved_ast_pb2.AnyResolvedExprProto, _Mapping]] = ..., resume_byte_position: _Optional[int] = ...) -> None: ...

class BuildSqlRequest(_message.Message):
    __slots__ = ("simple_catalog", "descriptor_pool_list", "registered_catalog_id", "resolved_statement", "resolved_expression")
    SIMPLE_CATALOG_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    simple_catalog: _simple_catalog_pb2.SimpleCatalogProto
    descriptor_pool_list: DescriptorPoolListProto
    registered_catalog_id: int
    resolved_statement: _resolved_ast_pb2.AnyResolvedStatementProto
    resolved_expression: _resolved_ast_pb2.AnyResolvedExprProto
    def __init__(self, simple_catalog: _Optional[_Union[_simple_catalog_pb2.SimpleCatalogProto, _Mapping]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., registered_catalog_id: _Optional[int] = ..., resolved_statement: _Optional[_Union[_resolved_ast_pb2.AnyResolvedStatementProto, _Mapping]] = ..., resolved_expression: _Optional[_Union[_resolved_ast_pb2.AnyResolvedExprProto, _Mapping]] = ...) -> None: ...

class BuildSqlResponse(_message.Message):
    __slots__ = ("sql",)
    SQL_FIELD_NUMBER: _ClassVar[int]
    sql: str
    def __init__(self, sql: _Optional[str] = ...) -> None: ...

class ExtractTableNamesFromStatementRequest(_message.Message):
    __slots__ = ("sql_statement", "options", "allow_script")
    SQL_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    ALLOW_SCRIPT_FIELD_NUMBER: _ClassVar[int]
    sql_statement: str
    options: _options_pb2.LanguageOptionsProto
    allow_script: bool
    def __init__(self, sql_statement: _Optional[str] = ..., options: _Optional[_Union[_options_pb2.LanguageOptionsProto, _Mapping]] = ..., allow_script: bool = ...) -> None: ...

class ExtractTableNamesFromStatementResponse(_message.Message):
    __slots__ = ("table_name",)
    class TableName(_message.Message):
        __slots__ = ("table_name_segment",)
        TABLE_NAME_SEGMENT_FIELD_NUMBER: _ClassVar[int]
        table_name_segment: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, table_name_segment: _Optional[_Iterable[str]] = ...) -> None: ...
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    table_name: _containers.RepeatedCompositeFieldContainer[ExtractTableNamesFromStatementResponse.TableName]
    def __init__(self, table_name: _Optional[_Iterable[_Union[ExtractTableNamesFromStatementResponse.TableName, _Mapping]]] = ...) -> None: ...

class ExtractTableNamesFromNextStatementRequest(_message.Message):
    __slots__ = ("parse_resume_location", "options")
    PARSE_RESUME_LOCATION_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    parse_resume_location: _parse_resume_location_pb2.ParseResumeLocationProto
    options: _options_pb2.LanguageOptionsProto
    def __init__(self, parse_resume_location: _Optional[_Union[_parse_resume_location_pb2.ParseResumeLocationProto, _Mapping]] = ..., options: _Optional[_Union[_options_pb2.LanguageOptionsProto, _Mapping]] = ...) -> None: ...

class ExtractTableNamesFromNextStatementResponse(_message.Message):
    __slots__ = ("table_name", "resume_byte_position")
    class TableName(_message.Message):
        __slots__ = ("table_name_segment",)
        TABLE_NAME_SEGMENT_FIELD_NUMBER: _ClassVar[int]
        table_name_segment: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, table_name_segment: _Optional[_Iterable[str]] = ...) -> None: ...
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    RESUME_BYTE_POSITION_FIELD_NUMBER: _ClassVar[int]
    table_name: _containers.RepeatedCompositeFieldContainer[ExtractTableNamesFromNextStatementResponse.TableName]
    resume_byte_position: int
    def __init__(self, table_name: _Optional[_Iterable[_Union[ExtractTableNamesFromNextStatementResponse.TableName, _Mapping]]] = ..., resume_byte_position: _Optional[int] = ...) -> None: ...

class FormatSqlRequest(_message.Message):
    __slots__ = ("sql", "options", "byte_ranges")
    SQL_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    BYTE_RANGES_FIELD_NUMBER: _ClassVar[int]
    sql: str
    options: _formatter_options_pb2.FormatterOptionsProto
    byte_ranges: _containers.RepeatedCompositeFieldContainer[_formatter_options_pb2.FormatterRangeProto]
    def __init__(self, sql: _Optional[str] = ..., options: _Optional[_Union[_formatter_options_pb2.FormatterOptionsProto, _Mapping]] = ..., byte_ranges: _Optional[_Iterable[_Union[_formatter_options_pb2.FormatterRangeProto, _Mapping]]] = ...) -> None: ...

class FormatSqlResponse(_message.Message):
    __slots__ = ("sql",)
    SQL_FIELD_NUMBER: _ClassVar[int]
    sql: str
    def __init__(self, sql: _Optional[str] = ...) -> None: ...

class RegisterCatalogRequest(_message.Message):
    __slots__ = ("simple_catalog", "descriptor_pool_list", "table_content")
    class TableContentEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: TableContent
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[TableContent, _Mapping]] = ...) -> None: ...
    SIMPLE_CATALOG_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_LIST_FIELD_NUMBER: _ClassVar[int]
    TABLE_CONTENT_FIELD_NUMBER: _ClassVar[int]
    simple_catalog: _simple_catalog_pb2.SimpleCatalogProto
    descriptor_pool_list: DescriptorPoolListProto
    table_content: _containers.MessageMap[str, TableContent]
    def __init__(self, simple_catalog: _Optional[_Union[_simple_catalog_pb2.SimpleCatalogProto, _Mapping]] = ..., descriptor_pool_list: _Optional[_Union[DescriptorPoolListProto, _Mapping]] = ..., table_content: _Optional[_Mapping[str, TableContent]] = ...) -> None: ...

class TableContent(_message.Message):
    __slots__ = ("table_data",)
    TABLE_DATA_FIELD_NUMBER: _ClassVar[int]
    table_data: TableData
    def __init__(self, table_data: _Optional[_Union[TableData, _Mapping]] = ...) -> None: ...

class TableData(_message.Message):
    __slots__ = ("row",)
    class Row(_message.Message):
        __slots__ = ("cell",)
        CELL_FIELD_NUMBER: _ClassVar[int]
        cell: _containers.RepeatedCompositeFieldContainer[_value_pb2.ValueProto]
        def __init__(self, cell: _Optional[_Iterable[_Union[_value_pb2.ValueProto, _Mapping]]] = ...) -> None: ...
    ROW_FIELD_NUMBER: _ClassVar[int]
    row: _containers.RepeatedCompositeFieldContainer[TableData.Row]
    def __init__(self, row: _Optional[_Iterable[_Union[TableData.Row, _Mapping]]] = ...) -> None: ...

class RegisterResponse(_message.Message):
    __slots__ = ("registered_id", "descriptor_pool_id_list")
    REGISTERED_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_POOL_ID_LIST_FIELD_NUMBER: _ClassVar[int]
    registered_id: int
    descriptor_pool_id_list: DescriptorPoolIdList
    def __init__(self, registered_id: _Optional[int] = ..., descriptor_pool_id_list: _Optional[_Union[DescriptorPoolIdList, _Mapping]] = ...) -> None: ...

class UnregisterRequest(_message.Message):
    __slots__ = ("registered_id",)
    REGISTERED_ID_FIELD_NUMBER: _ClassVar[int]
    registered_id: int
    def __init__(self, registered_id: _Optional[int] = ...) -> None: ...

class GetBuiltinFunctionsResponse(_message.Message):
    __slots__ = ("function", "types", "table_valued_function")
    class TypesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _type_pb2.TypeProto
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_type_pb2.TypeProto, _Mapping]] = ...) -> None: ...
    FUNCTION_FIELD_NUMBER: _ClassVar[int]
    TYPES_FIELD_NUMBER: _ClassVar[int]
    TABLE_VALUED_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    function: _containers.RepeatedCompositeFieldContainer[_function_pb2.FunctionProto]
    types: _containers.MessageMap[str, _type_pb2.TypeProto]
    table_valued_function: _containers.RepeatedCompositeFieldContainer[_function_pb2.TableValuedFunctionProto]
    def __init__(self, function: _Optional[_Iterable[_Union[_function_pb2.FunctionProto, _Mapping]]] = ..., types: _Optional[_Mapping[str, _type_pb2.TypeProto]] = ..., table_valued_function: _Optional[_Iterable[_Union[_function_pb2.TableValuedFunctionProto, _Mapping]]] = ...) -> None: ...

class LanguageOptionsRequest(_message.Message):
    __slots__ = ("maximum_features", "language_version")
    MAXIMUM_FEATURES_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_VERSION_FIELD_NUMBER: _ClassVar[int]
    maximum_features: bool
    language_version: _options_pb2_1.LanguageVersion
    def __init__(self, maximum_features: bool = ..., language_version: _Optional[_Union[_options_pb2_1.LanguageVersion, str]] = ...) -> None: ...

class AnalyzerOptionsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ParseRequest(_message.Message):
    __slots__ = ("sql_statement", "parse_resume_location", "options", "allow_script")
    SQL_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    PARSE_RESUME_LOCATION_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    ALLOW_SCRIPT_FIELD_NUMBER: _ClassVar[int]
    sql_statement: str
    parse_resume_location: _parse_resume_location_pb2.ParseResumeLocationProto
    options: _options_pb2.LanguageOptionsProto
    allow_script: bool
    def __init__(self, sql_statement: _Optional[str] = ..., parse_resume_location: _Optional[_Union[_parse_resume_location_pb2.ParseResumeLocationProto, _Mapping]] = ..., options: _Optional[_Union[_options_pb2.LanguageOptionsProto, _Mapping]] = ..., allow_script: bool = ...) -> None: ...

class ParseResponse(_message.Message):
    __slots__ = ("parsed_statement", "parsed_script", "resume_byte_position")
    PARSED_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    PARSED_SCRIPT_FIELD_NUMBER: _ClassVar[int]
    RESUME_BYTE_POSITION_FIELD_NUMBER: _ClassVar[int]
    parsed_statement: _parse_tree_pb2.AnyASTStatementProto
    parsed_script: _parse_tree_pb2.ASTScriptProto
    resume_byte_position: int
    def __init__(self, parsed_statement: _Optional[_Union[_parse_tree_pb2.AnyASTStatementProto, _Mapping]] = ..., parsed_script: _Optional[_Union[_parse_tree_pb2.ASTScriptProto, _Mapping]] = ..., resume_byte_position: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/functions/bitwise_agg_mode.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/functions/bitwise_agg_mode.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/zetasql/public/functions/bitwise_agg_mode.proto\x12\x11zetasql.functions\x1a\x19zetasql/public/type.proto\"z\n\x0f\x42itwiseAggEnums\"g\n\x0e\x42itwiseAggMode\x12&\n\x18\x42ITWISE_AGG_MODE_INVALID\x10\x00\x1a\x08\xb2\xf2\xb0\x92\x0e\x02\x08\x01\x12\n\n\x06STRICT\x10\x01\x12\x07\n\x03PAD\x10\x02\x1a\x18\xb2\xd0\xaf\xfa\r\x12\n\x10\x42ITWISE_AGG_MODEB5\n\x1c\x63om.google.zetasql.functionsB\x15ZetaSQLBitwiseAggMode')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.functions.bitwise_agg_mode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.zetasql.functionsB\025ZetaSQLBitwiseAggMode'
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE']._loaded_options = None
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE']._serialized_options = b'\262\320\257\372\r\022\n\020BITWISE_AGG_MODE'
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE'].values_by_name["BITWISE_AGG_MODE_INVALID"]._loaded_options = None
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE'].values_by_name["BITWISE_AGG_MODE_INVALID"]._serialized_options = b'\262\362\260\222\016\002\010\001'
  _globals['_BITWISEAGGENUMS']._serialized_start=97
  _globals['_BITWISEAGGENUMS']._serialized_end=219
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE']._serialized_start=116
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE']._serialized_end=219
# @@protoc_insertion_point(module_scope)



"""Value wrapper for ZetaSQL typed values.

Provides Java-style Value API wrapping the proto-based Value ProtoModel.
Mirrors Java's Value class for creating and manipulating typed SQL values.
"""

import datetime
from typing import Any

from google.protobuf.timestamp_pb2 import Timestamp

from zetasql import types
from zetasql.types import TypeKind


class Value:
    """Wrapper for ZetaSQL Value ProtoModel with Java-style API.

    Provides factory methods for creating typed values and accessor methods
    for retrieving typed data. Wraps the underlying Value ProtoModel from
    zetasql.types.

    Example:
        >>> # Create values
        >>> v1 = Value.int64(42)
        >>> v2 = Value.string("hello")
        >>> v3 = Value.null(TypeKind.TYPE_INT64)
        >>>
        >>> # Access values
        >>> assert v1.get_int64() == 42
        >>> assert v2.get_string() == "hello"
        >>> assert v3.is_null()
    """

    def __init__(self, proto_value: types.Value, type_kind: TypeKind | None = None):
        """Initialize Value wrapper from ProtoModel Value.

        Args:
            proto_value: Value ProtoModel from zetasql.types
            type_kind: Optional TypeKind for null values (since proto doesn't store type for nulls)
        """
        self._proto = proto_value
        self._type_kind = type_kind  # Only used for null values
        self._field_names: list[str] | None = None  # For STRUCT field names
        self._element_metadata: list[dict[str, Any]] | None = None  # For ARRAY element metadata

    @property
    def type_kind(self) -> TypeKind:
        """Get the TypeKind of this value.

        Returns:
            TypeKind enum value
        """
        if self._type_kind is not None:
            return self._type_kind

        # Map proto field names to TypeKind values
        field_to_type = {
            "int64_value": TypeKind.TYPE_INT64,
            "string_value": TypeKind.TYPE_STRING,
            "bool_value": TypeKind.TYPE_BOOL,
            "double_value": TypeKind.TYPE_DOUBLE,
            "int32_value": TypeKind.TYPE_INT32,
            "float_value": TypeKind.TYPE_FLOAT,
            "date_value": TypeKind.TYPE_DATE,
            "timestamp_value": TypeKind.TYPE_TIMESTAMP,
            "array_value": TypeKind.TYPE_ARRAY,
            "struct_value": TypeKind.TYPE_STRUCT,
        }

        for field_name, type_kind in field_to_type.items():
            if getattr(self._proto, field_name) is not None:
                return type_kind

        return TypeKind.TYPE_UNKNOWN

    def is_null(self) -> bool:
        """Check if this value is NULL.

        Returns:
            True if value is NULL
        """
        return all(
            getattr(self._proto, field) is None
            for field in [
                "int32_value",
                "int64_value",
                "uint32_value",
                "uint64_value",
                "bool_value",
                "float_value",
                "double_value",
                "string_value",
                "bytes_value",
                "date_value",
                "timestamp_value",
                "array_value",
                "struct_value",
            ]
        )

    def get_int64(self) -> int:
        """Get INT64 value.

        Returns:
            Python int

        Raises:
            ValueError: If type is not INT64 or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_INT64:
            raise ValueError(f"Type mismatch: expected INT64, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        return self._proto.int64_value

    def get_string(self) -> str:
        """Get STRING value.

        Returns:
            Python str

        Raises:
            ValueError: If type is not STRING or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_STRING:
            raise ValueError(f"Type mismatch: expected STRING, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        return self._proto.string_value

    def get_bool(self) -> bool:
        """Get BOOL value.

        Returns:
            Python bool

        Raises:
            ValueError: If type is not BOOL or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_BOOL:
            raise ValueError(f"Type mismatch: expected BOOL, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        return self._proto.bool_value

    def get_double(self) -> float:
        """Get DOUBLE value.

        Returns:
            Python float

        Raises:
            ValueError: If type is not DOUBLE or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_DOUBLE:
            raise ValueError(f"Type mismatch: expected DOUBLE, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        return self._proto.double_value

    def get_int32(self) -> int:
        """Get INT32 value.

        Returns:
            Python int

        Raises:
            ValueError: If type is not INT32 or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_INT32:
            raise ValueError(f"Type mismatch: expected INT32, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        return self._proto.int32_value

    def get_float(self) -> float:
        """Get FLOAT value.

        Returns:
            Python float

        Raises:
            ValueError: If type is not FLOAT or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_FLOAT:
            raise ValueError(f"Type mismatch: expected FLOAT, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        return self._proto.float_value

    def get_date(self) -> "datetime.date":
        """Get DATE value.

        Returns:
            Python date

        Raises:
            ValueError: If type is not DATE or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_DATE:
            raise ValueError(f"Type mismatch: expected DATE, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        epoch = datetime.date(1970, 1, 1)
        return epoch + datetime.timedelta(days=self._proto.date_value)

    def get_timestamp(self) -> "datetime.datetime":
        """Get TIMESTAMP value.

        Returns:
            Python datetime

        Raises:
            ValueError: If type is not TIMESTAMP or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_TIMESTAMP:
            raise ValueError(f"Type mismatch: expected TIMESTAMP, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        return self._proto.timestamp_value.ToDatetime()

    def get_array_size(self) -> int:
        """Get size of ARRAY value.

        Returns:
            Number of elements in array

        Raises:
            ValueError: If type is not ARRAY or value is NULL
        """
        if self.type_kind != TypeKind.TYPE_ARRAY:
            raise ValueError(f"Type mismatch: expected ARRAY, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        return len(self._proto.array_value.element)

    def get_array_element(self, index: int) -> "Value":
        """Get element from ARRAY value.

        Args:
            index: Element index (0-based)

        Returns:
            Value at the given index

        Raises:
            ValueError: If type is not ARRAY or value is NULL
            IndexError: If index out of range
        """
        if self.type_kind != TypeKind.TYPE_ARRAY:
            raise ValueError(f"Type mismatch: expected ARRAY, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        if index < 0 or index >= len(self._proto.array_value.element):
            raise IndexError(f"Array index {index} out of range")

        # Create Value from proto element
        elem_value = Value(self._proto.array_value.element[index])

        # Restore metadata if available
        if self._element_metadata and index < len(self._element_metadata):
            metadata = self._element_metadata[index]
            if "field_names" in metadata:
                elem_value._field_names = metadata["field_names"]

        return elem_value

    def get_field(self, field_name: str) -> "Value":
        """Get field from STRUCT value by name.

        Args:
            field_name: Name of the field

        Returns:
            Value of the field

        Raises:
            ValueError: If type is not STRUCT or value is NULL
            KeyError: If field not found
        """
        if self.type_kind != TypeKind.TYPE_STRUCT:
            raise ValueError(f"Type mismatch: expected STRUCT, got {self.type_kind}")
        if self.is_null():
            raise ValueError("Cannot get value from NULL")
        if self._field_names is None:
            raise ValueError("STRUCT field names not available")
        if field_name not in self._field_names:
            raise KeyError(f"Field '{field_name}' not found in STRUCT")

        index = self._field_names.index(field_name)
        return Value(self._proto.struct_value.field[index])

    # Factory methods for creating values

    @staticmethod
    def int64(value: int) -> "Value":
        """Create INT64 value.

        Args:
            value: Python int

        Returns:
            Value wrapper

        Example:
            >>> v = Value.int64(42)
            >>> assert v.get_int64() == 42
        """
        proto = types.Value(int64_value=value)
        return Value(proto)

    @staticmethod
    def string(value: str) -> "Value":
        """Create STRING value.

        Args:
            value: Python str

        Returns:
            Value wrapper

        Example:
            >>> v = Value.string("hello")
            >>> assert v.get_string() == "hello"
        """
        proto = types.Value(string_value=value)
        return Value(proto)

    @staticmethod
    def bool(value: bool) -> "Value":
        """Create BOOL value.

        Args:
            value: Python bool

        Returns:
            Value wrapper

        Example:
            >>> v = Value.bool(True)
            >>> assert v.get_bool() is True
        """
        proto = types.Value(bool_value=value)
        return Value(proto)

    @staticmethod
    def double(value: float) -> "Value":
        """Create DOUBLE value.

        Args:
            value: Python float

        Returns:
            Value wrapper

        Example:
            >>> v = Value.double(3.14)
            >>> assert abs(v.get_double() - 3.14) < 0.001
        """
        proto = types.Value(double_value=value)
        return Value(proto)

    @staticmethod
    def int32(value: int) -> "Value":
        """Create INT32 value.

        Args:
            value: Python int

        Returns:
            Value wrapper
        """
        proto = types.Value(int32_value=value)
        return Value(proto)

    @staticmethod
    def float_value(value: float) -> "Value":
        """Create FLOAT value.

        Args:
            value: Python float

        Returns:
            Value wrapper
        """
        proto = types.Value(float_value=value)
        return Value(proto)

    @staticmethod
    def date(year: int, month: int, day: int) -> "Value":
        """Create DATE value.

        Args:
            year: Year
            month: Month (1-12)
            day: Day (1-31)

        Returns:
            Value wrapper

        Example:
            >>> v = Value.date(2024, 1, 15)
            >>> assert v.get_date().year == 2024
        """
        epoch = datetime.date(1970, 1, 1)
        target_date = datetime.date(year, month, day)
        days_since_epoch = (target_date - epoch).days
        proto = types.Value(date_value=days_since_epoch)
        return Value(proto)

    @staticmethod
    def timestamp(dt: "datetime.datetime") -> "Value":
        """Create TIMESTAMP value.

        Args:
            dt: Python datetime

        Returns:
            Value wrapper

        Example:
            >>> import datetime
            >>> dt = datetime.datetime(2024, 1, 15, 10, 30, 45)
            >>> v = Value.timestamp(dt)
            >>> assert v.get_timestamp() == dt
        """
        timestamp_proto = Timestamp()
        timestamp_proto.FromDatetime(dt)
        proto = types.Value(timestamp_value=timestamp_proto)
        return Value(proto)

    @staticmethod
    def null(type_kind: TypeKind) -> "Value":
        """Create NULL value of specified type.

        Args:
            type_kind: TypeKind for the NULL value

        Returns:
            Value wrapper representing NULL

        Example:
            >>> v = Value.null(TypeKind.TYPE_INT64)
            >>> assert v.is_null()
            >>> assert v.type_kind == TypeKind.TYPE_INT64
        """
        proto = types.Value()
        return Value(proto, type_kind=type_kind)

    @staticmethod
    def array(elements: list["Value"]) -> "Value":
        """Create ARRAY value.

        Args:
            elements: List of Value elements

        Returns:
            Value wrapper representing ARRAY

        Example:
            >>> elements = [Value.int64(1), Value.int64(2), Value.int64(3)]
            >>> arr = Value.array(elements)
            >>> arr.get_array_size() == 3
        """
        proto_elements = [elem.to_proto() for elem in elements]
        array_proto = types.Value.Array(element=proto_elements)
        proto = types.Value(array_value=array_proto)

        value_obj = Value(proto)
        value_obj._element_metadata = [
            {"field_names": elem._field_names} if elem._field_names is not None else {} for elem in elements
        ]
        return value_obj

    @staticmethod
    def struct(fields: dict[str, "Value"]) -> "Value":
        """Create STRUCT value.

        Args:
            fields: Dictionary mapping field names to Values

        Returns:
            Value wrapper representing STRUCT

        Example:
            >>> s = Value.struct({
            ...     "name": Value.string("Alice"),
            ...     "age": Value.int64(30)
            ... })
            >>> s.get_field("name").get_string() == "Alice"
        """
        proto_fields = [value.to_proto() for value in fields.values()]
        struct_proto = types.Value.Struct(field=proto_fields)
        proto = types.Value(struct_value=struct_proto)

        value_obj = Value(proto)
        value_obj._field_names = list(fields.keys())
        return value_obj

    @staticmethod
    def from_proto(proto: types.Value) -> "Value":
        """Create Value wrapper from ProtoModel Value.

        Args:
            proto: Value ProtoModel

        Returns:
            Value wrapper
        """
        return Value(proto)

    def to_proto(self) -> types.Value:
        """Get underlying ProtoModel Value.

        Returns:
            Value ProtoModel
        """
        return self._proto

    def equals(self, other: "Value") -> bool:
        """Check equality with another Value.

        Args:
            other: Another Value to compare

        Returns:
            True if values are equal
        """
        if not isinstance(other, Value):
            return False

        if self.type_kind != other.type_kind:
            return False

        if self.is_null() and other.is_null():
            return True

        if self.is_null() != other.is_null():
            return False

        type_to_getter = {
            TypeKind.TYPE_INT64: lambda v: v.get_int64(),
            TypeKind.TYPE_STRING: lambda v: v.get_string(),
            TypeKind.TYPE_BOOL: lambda v: v.get_bool(),
            TypeKind.TYPE_DOUBLE: lambda v: v.get_double(),
            TypeKind.TYPE_INT32: lambda v: v.get_int32(),
            TypeKind.TYPE_FLOAT: lambda v: v.get_float(),
            TypeKind.TYPE_DATE: lambda v: v.get_date(),
            TypeKind.TYPE_TIMESTAMP: lambda v: v.get_timestamp(),
        }

        getter = type_to_getter.get(self.type_kind)
        if getter:
            return getter(self) == getter(other)

        return self._proto == other._proto

    def compare_to(self, other: "Value") -> int:
        """Compare this value to another.

        Args:
            other: Another Value to compare

        Returns:
            -1 if self < other, 0 if equal, 1 if self > other

        Raises:
            ValueError: If types don't match or values are NULL
        """
        if not isinstance(other, Value):
            raise ValueError("Can only compare with another Value")

        if self.type_kind != other.type_kind:
            raise ValueError(f"Cannot compare different types: {self.type_kind} vs {other.type_kind}")

        if self.is_null() or other.is_null():
            raise ValueError("Cannot compare NULL values")

        type_to_getter = {
            TypeKind.TYPE_INT64: lambda v: v.get_int64(),
            TypeKind.TYPE_INT32: lambda v: v.get_int32(),
            TypeKind.TYPE_DOUBLE: lambda v: v.get_double(),
            TypeKind.TYPE_FLOAT: lambda v: v.get_float(),
            TypeKind.TYPE_STRING: lambda v: v.get_string(),
            TypeKind.TYPE_BOOL: lambda v: v.get_bool(),
            TypeKind.TYPE_DATE: lambda v: v.get_date(),
            TypeKind.TYPE_TIMESTAMP: lambda v: v.get_timestamp(),
        }

        getter = type_to_getter.get(self.type_kind)
        if not getter:
            raise ValueError(f"Comparison not supported for type {self.type_kind}")

        a, b = getter(self), getter(other)
        return -1 if a < b else (1 if a > b else 0)

    def to_sql_literal(self) -> str:
        """Convert value to SQL literal string.

        Returns:
            SQL literal representation

        Example:
            >>> Value.int64(42).to_sql_literal()
            '42'
            >>> Value.string("hello").to_sql_literal()
            "'hello'"
        """
        if self.is_null():
            return "NULL"

        if self.type_kind == TypeKind.TYPE_STRING:
            escaped = self.get_string().replace("'", "''")
            return f"'{escaped}'"

        type_to_sql = {
            TypeKind.TYPE_BOOL: lambda: "TRUE" if self.get_bool() else "FALSE",
            TypeKind.TYPE_INT64: lambda: str(self.get_int64()),
            TypeKind.TYPE_INT32: lambda: str(self.get_int32()),
            TypeKind.TYPE_DOUBLE: lambda: str(self.get_double()),
            TypeKind.TYPE_FLOAT: lambda: str(self.get_float()),
            TypeKind.TYPE_DATE: lambda: f"DATE '{self.get_date().isoformat()}'",
            TypeKind.TYPE_TIMESTAMP: lambda: f"TIMESTAMP '{self.get_timestamp().isoformat()}'",
        }

        converter = type_to_sql.get(self.type_kind)
        return converter() if converter else str(self)

    def __str__(self) -> str:
        """String representation of the value.

        Returns:
            String representation matching SQL literals
        """
        if self.is_null():
            return "NULL"

        type_to_str = {
            TypeKind.TYPE_STRING: lambda: f'"{self.get_string()}"',
            TypeKind.TYPE_BOOL: lambda: "true" if self.get_bool() else "false",
            TypeKind.TYPE_INT64: lambda: str(self.get_int64()),
            TypeKind.TYPE_INT32: lambda: str(self.get_int32()),
            TypeKind.TYPE_DOUBLE: lambda: str(self.get_double()),
            TypeKind.TYPE_FLOAT: lambda: str(self.get_float()),
            TypeKind.TYPE_DATE: lambda: str(self.get_date()),
            TypeKind.TYPE_TIMESTAMP: lambda: str(self.get_timestamp()),
        }

        converter = type_to_str.get(self.type_kind)
        return converter() if converter else f"Value({self.type_kind})"

    def __repr__(self) -> str:
        """Developer representation."""
        return f"Value({self._proto})"

    def get_type(self) -> "types.Type":
        """Get the Type of this value.

        Mirrors Java's Value.getType() method for type introspection.

        Returns:
            Type object representing this value's type

        Example:
            >>> v = Value.int64(42)
            >>> t = v.get_type()
            >>> assert t.type_kind == TypeKind.TYPE_INT64
        """
        return types.Type(type_kind=self.type_kind)

    def __iter__(self):
        """Iterate over ARRAY elements.

        Yields:
            Value: Each element in the array

        Raises:
            ValueError: If type is not ARRAY
        """
        if self.type_kind != TypeKind.TYPE_ARRAY:
            raise ValueError(f"Cannot iterate over non-ARRAY type: {self.type_kind}")

        for i in range(self.get_array_size()):
            yield self.get_array_element(i)

    def coerce_to(self, target_type: TypeKind) -> "Value":
        """Coerce value to a different type.

        Type coercion attempts to convert a value to another compatible type
        following SQL coercion rules (e.g., INT64 -> STRING, INT32 -> INT64).

        Args:
            target_type: Target TypeKind to coerce to

        Returns:
            New Value with coerced type

        Raises:
            ValueError: If coercion is not supported

        Example:
            >>> v = Value.int64(42)
            >>> s = v.coerce_to(TypeKind.TYPE_STRING)
            >>> s.get_string() == "42"
        """
        if self.type_kind == target_type:
            return self

        if self.is_null():
            return Value.null(target_type)

        # Define coercion rules as nested dict: source_type -> target_type -> converter
        coercion_rules = {
            TypeKind.TYPE_INT64: {
                TypeKind.TYPE_STRING: lambda: Value.string(str(self.get_int64())),
                TypeKind.TYPE_DOUBLE: lambda: Value.double(float(self.get_int64())),
                TypeKind.TYPE_FLOAT: lambda: Value.float_value(float(self.get_int64())),
            },
            TypeKind.TYPE_INT32: {
                TypeKind.TYPE_INT64: lambda: Value.int64(self.get_int32()),
                TypeKind.TYPE_STRING: lambda: Value.string(str(self.get_int32())),
                TypeKind.TYPE_DOUBLE: lambda: Value.double(float(self.get_int32())),
                TypeKind.TYPE_FLOAT: lambda: Value.float_value(float(self.get_int32())),
            },
            TypeKind.TYPE_DOUBLE: {
                TypeKind.TYPE_STRING: lambda: Value.string(str(self.get_double())),
            },
            TypeKind.TYPE_FLOAT: {
                TypeKind.TYPE_DOUBLE: lambda: Value.double(self.get_float()),
                TypeKind.TYPE_STRING: lambda: Value.string(str(self.get_float())),
            },
            TypeKind.TYPE_BOOL: {
                TypeKind.TYPE_STRING: lambda: Value.string("true" if self.get_bool() else "false"),
                TypeKind.TYPE_INT64: lambda: Value.int64(1 if self.get_bool() else 0),
            },
            TypeKind.TYPE_DATE: {
                TypeKind.TYPE_STRING: lambda: Value.string(self.get_date().isoformat()),
            },
            TypeKind.TYPE_TIMESTAMP: {
                TypeKind.TYPE_STRING: lambda: Value.string(self.get_timestamp().isoformat()),
            },
        }

        converter = coercion_rules.get(self.type_kind, {}).get(target_type)
        if converter:
            return converter()

        raise ValueError(f"Cannot coerce {self.type_kind} to {target_type}")

    def cast_to(self, target_type: TypeKind) -> "Value":
        """Cast value to a different type with explicit conversion.

        Type casting is more aggressive than coercion and may fail at runtime
        if the conversion is invalid (e.g., "abc" -> INT64).

        Args:
            target_type: Target TypeKind to cast to

        Returns:
            New Value with cast type

        Raises:
            ValueError: If cast fails or is not supported

        Example:
            >>> v = Value.string("123")
            >>> i = v.cast_to(TypeKind.TYPE_INT64)
            >>> i.get_int64() == 123
        """
        if self.type_kind == target_type:
            return self

        if self.is_null():
            return Value.null(target_type)

        # STRING casts (parse from string)
        if self.type_kind == TypeKind.TYPE_STRING:
            return self._cast_from_string(target_type)

        # Numeric casts
        if self.type_kind in (TypeKind.TYPE_INT64, TypeKind.TYPE_INT32, TypeKind.TYPE_DOUBLE, TypeKind.TYPE_FLOAT):
            return self._cast_from_numeric(target_type)

        # Try coercion as fallback
        try:
            return self.coerce_to(target_type)
        except ValueError as e:
            raise ValueError(f"Cannot cast {self.type_kind} to {target_type}") from e

    def _cast_from_string(self, target_type: TypeKind) -> "Value":
        """Cast STRING value to target type."""
        s = self.get_string()

        cast_functions = {
            TypeKind.TYPE_INT64: lambda: Value.int64(int(s)),
            TypeKind.TYPE_INT32: lambda: Value.int32(int(s)),
            TypeKind.TYPE_DOUBLE: lambda: Value.double(float(s)),
            TypeKind.TYPE_FLOAT: lambda: Value.float_value(float(s)),
            TypeKind.TYPE_BOOL: self._parse_bool_from_string,
        }

        caster = cast_functions.get(target_type)
        if not caster:
            raise ValueError(f"Cannot cast STRING to {target_type}")

        try:
            return caster()
        except (ValueError, OverflowError) as e:
            raise ValueError(f"Cannot cast STRING '{s}' to {target_type}: {e}") from e

    def _parse_bool_from_string(self) -> "Value":
        """Parse boolean value from string."""
        s = self.get_string().lower()
        if s in ("true", "t", "1", "yes"):
            return Value.bool(True)
        if s in ("false", "f", "0", "no"):
            return Value.bool(False)
        raise ValueError(f"Cannot parse '{s}' as BOOL")

    def _cast_from_numeric(self, target_type: TypeKind) -> "Value":
        """Cast numeric value to target type."""
        # Get numeric value based on source type
        value_getters = {
            TypeKind.TYPE_INT64: self.get_int64,
            TypeKind.TYPE_INT32: self.get_int32,
            TypeKind.TYPE_DOUBLE: self.get_double,
            TypeKind.TYPE_FLOAT: self.get_float,
        }

        val = value_getters[self.type_kind]()

        cast_functions = {
            TypeKind.TYPE_INT64: lambda: Value.int64(int(val)),
            TypeKind.TYPE_INT32: lambda: Value.int32(int(val)),
            TypeKind.TYPE_DOUBLE: lambda: Value.double(float(val)),
            TypeKind.TYPE_FLOAT: lambda: Value.float_value(float(val)),
            TypeKind.TYPE_STRING: lambda: Value.string(str(val)),
            TypeKind.TYPE_BOOL: lambda: Value.bool(val != 0),
        }

        caster = cast_functions.get(target_type)
        if not caster:
            raise ValueError(f"Cannot cast {self.type_kind} to {target_type}")

        try:
            return caster()
        except (ValueError, OverflowError) as e:
            raise ValueError(f"Cannot cast {self.type_kind} to {target_type}: {e}") from e



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/function.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/function.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dzetasql/public/function.proto\x12\x07zetasql\"\xa0\x08\n\rFunctionEnums\"?\n\x13\x41rgumentCardinality\x12\x0c\n\x08REQUIRED\x10\x00\x12\x0c\n\x08REPEATED\x10\x01\x12\x0c\n\x08OPTIONAL\x10\x02\"@\n\x15ProcedureArgumentMode\x12\x0b\n\x07NOT_SET\x10\x00\x12\x06\n\x02IN\x10\x01\x12\x07\n\x03OUT\x10\x02\x12\t\n\x05INOUT\x10\x03\"S\n\x12WindowOrderSupport\x12\x15\n\x11ORDER_UNSUPPORTED\x10\x00\x12\x12\n\x0eORDER_OPTIONAL\x10\x01\x12\x12\n\x0eORDER_REQUIRED\x10\x02\"/\n\x04Mode\x12\n\n\x06SCALAR\x10\x01\x12\r\n\tAGGREGATE\x10\x02\x12\x0c\n\x08\x41NALYTIC\x10\x03\"5\n\nVolatility\x12\r\n\tIMMUTABLE\x10\x00\x12\n\n\x06STABLE\x10\x01\x12\x0c\n\x08VOLATILE\x10\x02\"\xd9\x01\n\x17TableValuedFunctionType\x12\x0b\n\x07INVALID\x10\x00\x12\x1b\n\x17\x46IXED_OUTPUT_SCHEMA_TVF\x10\x01\x12-\n)FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_TVF\x10\x02\x12\x15\n\x11TEMPLATED_SQL_TVF\x10\x03\x12?\n;FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_WITH_APPENDED_COLUMNS\x10\x07\x12\r\n\tBASIS_TVF\x10\x08\"\x80\x01\n\x15\x41rgumentCollationMode\x12\x10\n\x0c\x41\x46\x46\x45\x43TS_NONE\x10\x00\x12\x15\n\x11\x41\x46\x46\x45\x43TS_OPERATION\x10\x01\x12\x17\n\x13\x41\x46\x46\x45\x43TS_PROPAGATION\x10\x02\x12%\n!AFFECTS_OPERATION_AND_PROPAGATION\x10\x03\"v\n\x11NamedArgumentKind\x12#\n\x1fNAMED_ARGUMENT_KIND_UNSPECIFIED\x10\x00\x12\x13\n\x0fPOSITIONAL_ONLY\x10\x01\x12\x17\n\x13POSITIONAL_OR_NAMED\x10\x02\x12\x0e\n\nNAMED_ONLY\x10\x03\"h\n\x11\x41rgumentAliasKind\x12#\n\x1f\x41RGUMENT_ALIAS_KIND_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41RGUMENT_NON_ALIASED\x10\x01\x12\x14\n\x10\x41RGUMENT_ALIASED\x10\x02\"\x8d\x01\n\x13\x44\x65\x66\x61ultNullHandling\x12%\n!DEFAULT_NULL_HANDLING_UNSPECIFIED\x10\x00\x12&\n\"DEFAULT_NULL_HANDLING_IGNORE_NULLS\x10\x01\x12\'\n#DEFAULT_NULL_HANDLING_RESPECT_NULLS\x10\x02*\xdc\x06\n\x15SignatureArgumentKind\x12\x12\n\x0e\x41RG_TYPE_FIXED\x10\x00\x12\x12\n\x0e\x41RG_TYPE_ANY_1\x10\x01\x12\x12\n\x0e\x41RG_TYPE_ANY_2\x10\x02\x12\x12\n\x0e\x41RG_TYPE_ANY_3\x10\x17\x12\x12\n\x0e\x41RG_TYPE_ANY_4\x10\x19\x12\x12\n\x0e\x41RG_TYPE_ANY_5\x10\x1b\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_1\x10\x03\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_2\x10\x04\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_3\x10\x18\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_4\x10\x1a\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_5\x10\x1c\x12\x15\n\x11\x41RG_PROTO_MAP_ANY\x10\x0e\x12\x19\n\x15\x41RG_PROTO_MAP_KEY_ANY\x10\x0f\x12\x1b\n\x17\x41RG_PROTO_MAP_VALUE_ANY\x10\x10\x12\x11\n\rARG_PROTO_ANY\x10\x05\x12\x12\n\x0e\x41RG_STRUCT_ANY\x10\x06\x12\x10\n\x0c\x41RG_ENUM_ANY\x10\x07\x12\x16\n\x12\x41RG_TYPE_ARBITRARY\x10\x08\x12\x15\n\x11\x41RG_TYPE_RELATION\x10\t\x12\x11\n\rARG_TYPE_VOID\x10\n\x12\x12\n\x0e\x41RG_TYPE_MODEL\x10\x0b\x12\x17\n\x13\x41RG_TYPE_CONNECTION\x10\x0c\x12\x17\n\x13\x41RG_TYPE_DESCRIPTOR\x10\r\x12\x13\n\x0f\x41RG_TYPE_LAMBDA\x10\x11\x12\x18\n\x14\x41RG_RANGE_TYPE_ANY_1\x10\x12\x12\x17\n\x13\x41RG_TYPE_GRAPH_NODE\x10\x13\x12\x17\n\x13\x41RG_TYPE_GRAPH_EDGE\x10\x14\x12\x1a\n\x16\x41RG_TYPE_GRAPH_ELEMENT\x10\x15\x12\x17\n\x13\x41RG_TYPE_GRAPH_PATH\x10\x1e\x12\x12\n\x0e\x41RG_TYPE_GRAPH\x10 \x12\x15\n\x11\x41RG_TYPE_SEQUENCE\x10\x16\x12\x1a\n\x16\x41RG_MEASURE_TYPE_ANY_1\x10\x1f\x12\x18\n\x14\x41RG_MAP_TYPE_ANY_1_2\x10\x1d\x12\x42\n5__SignatureArgumentKind__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x42&\n\x12\x63om.google.zetasqlB\x10ZetaSQLFunctions')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.function_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\020ZetaSQLFunctions'
  _globals['_SIGNATUREARGUMENTKIND']._serialized_start=1102
  _globals['_SIGNATUREARGUMENTKIND']._serialized_end=1962
  _globals['_FUNCTIONENUMS']._serialized_start=43
  _globals['_FUNCTIONENUMS']._serialized_end=1099
  _globals['_FUNCTIONENUMS_ARGUMENTCARDINALITY']._serialized_start=60
  _globals['_FUNCTIONENUMS_ARGUMENTCARDINALITY']._serialized_end=123
  _globals['_FUNCTIONENUMS_PROCEDUREARGUMENTMODE']._serialized_start=125
  _globals['_FUNCTIONENUMS_PROCEDUREARGUMENTMODE']._serialized_end=189
  _globals['_FUNCTIONENUMS_WINDOWORDERSUPPORT']._serialized_start=191
  _globals['_FUNCTIONENUMS_WINDOWORDERSUPPORT']._serialized_end=274
  _globals['_FUNCTIONENUMS_MODE']._serialized_start=276
  _globals['_FUNCTIONENUMS_MODE']._serialized_end=323
  _globals['_FUNCTIONENUMS_VOLATILITY']._serialized_start=325
  _globals['_FUNCTIONENUMS_VOLATILITY']._serialized_end=378
  _globals['_FUNCTIONENUMS_TABLEVALUEDFUNCTIONTYPE']._serialized_start=381
  _globals['_FUNCTIONENUMS_TABLEVALUEDFUNCTIONTYPE']._serialized_end=598
  _globals['_FUNCTIONENUMS_ARGUMENTCOLLATIONMODE']._serialized_start=601
  _globals['_FUNCTIONENUMS_ARGUMENTCOLLATIONMODE']._serialized_end=729
  _globals['_FUNCTIONENUMS_NAMEDARGUMENTKIND']._serialized_start=731
  _globals['_FUNCTIONENUMS_NAMEDARGUMENTKIND']._serialized_end=849
  _globals['_FUNCTIONENUMS_ARGUMENTALIASKIND']._serialized_start=851
  _globals['_FUNCTIONENUMS_ARGUMENTALIASKIND']._serialized_end=955
  _globals['_FUNCTIONENUMS_DEFAULTNULLHANDLING']._serialized_start=958
  _globals['_FUNCTIONENUMS_DEFAULTNULLHANDLING']._serialized_end=1099
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnonOutputWithReport(_message.Message):
    __slots__ = ("value", "values", "bounding_report")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    BOUNDING_REPORT_FIELD_NUMBER: _ClassVar[int]
    value: AnonOutputValue
    values: AnonOutputValues
    bounding_report: BoundingReport
    def __init__(self, value: _Optional[_Union[AnonOutputValue, _Mapping]] = ..., values: _Optional[_Union[AnonOutputValues, _Mapping]] = ..., bounding_report: _Optional[_Union[BoundingReport, _Mapping]] = ...) -> None: ...

class BoundingReport(_message.Message):
    __slots__ = ("lower_bound", "upper_bound", "num_inputs", "num_outside")
    LOWER_BOUND_FIELD_NUMBER: _ClassVar[int]
    UPPER_BOUND_FIELD_NUMBER: _ClassVar[int]
    NUM_INPUTS_FIELD_NUMBER: _ClassVar[int]
    NUM_OUTSIDE_FIELD_NUMBER: _ClassVar[int]
    lower_bound: AnonOutputValue
    upper_bound: AnonOutputValue
    num_inputs: float
    num_outside: float
    def __init__(self, lower_bound: _Optional[_Union[AnonOutputValue, _Mapping]] = ..., upper_bound: _Optional[_Union[AnonOutputValue, _Mapping]] = ..., num_inputs: _Optional[float] = ..., num_outside: _Optional[float] = ...) -> None: ...

class NoiseConfidenceInterval(_message.Message):
    __slots__ = ("lower_bound", "upper_bound", "confidence_level")
    LOWER_BOUND_FIELD_NUMBER: _ClassVar[int]
    UPPER_BOUND_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_LEVEL_FIELD_NUMBER: _ClassVar[int]
    lower_bound: float
    upper_bound: float
    confidence_level: float
    def __init__(self, lower_bound: _Optional[float] = ..., upper_bound: _Optional[float] = ..., confidence_level: _Optional[float] = ...) -> None: ...

class AnonOutputValues(_message.Message):
    __slots__ = ("values",)
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedCompositeFieldContainer[AnonOutputValue]
    def __init__(self, values: _Optional[_Iterable[_Union[AnonOutputValue, _Mapping]]] = ...) -> None: ...

class AnonOutputValue(_message.Message):
    __slots__ = ("int_value", "float_value", "string_value", "noise_confidence_interval")
    INT_VALUE_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    NOISE_CONFIDENCE_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    int_value: int
    float_value: float
    string_value: str
    noise_confidence_interval: NoiseConfidenceInterval
    def __init__(self, int_value: _Optional[int] = ..., float_value: _Optional[float] = ..., string_value: _Optional[str] = ..., noise_confidence_interval: _Optional[_Union[NoiseConfidenceInterval, _Mapping]] = ...) -> None: ...



from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class RankTypeEnums(_message.Message):
    __slots__ = ()
    class RankType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        RANK_TYPE_UNKNOWN: _ClassVar[RankTypeEnums.RankType]
        FRACTION_LESS_THAN_OR_EQUAL: _ClassVar[RankTypeEnums.RankType]
        MIDPOINT: _ClassVar[RankTypeEnums.RankType]
        FRACTION_LESS_THAN: _ClassVar[RankTypeEnums.RankType]
    RANK_TYPE_UNKNOWN: RankTypeEnums.RankType
    FRACTION_LESS_THAN_OR_EQUAL: RankTypeEnums.RankType
    MIDPOINT: RankTypeEnums.RankType
    FRACTION_LESS_THAN: RankTypeEnums.RankType
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/scripting/script_executor_state.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/scripting/script_executor_state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from zetasql.wasi._pb2.zetasql.proto import function_pb2 as zetasql_dot_proto_dot_function__pb2
from zetasql.wasi._pb2.zetasql.proto import script_exception_pb2 as zetasql_dot_proto_dot_script__exception__pb2
from zetasql.wasi._pb2.zetasql.scripting import procedure_extension_pb2 as zetasql_dot_scripting_dot_procedure__extension__pb2
from zetasql.wasi._pb2.zetasql.scripting import variable_pb2 as zetasql_dot_scripting_dot_variable__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-zetasql/scripting/script_executor_state.proto\x12\x07zetasql\x1a\x19google/protobuf/any.proto\x1a\x1czetasql/proto/function.proto\x1a$zetasql/proto/script_exception.proto\x1a+zetasql/scripting/procedure_extension.proto\x1a zetasql/scripting/variable.proto\"\xaa\n\n\x18ScriptExecutorStateProto\x12?\n\tcallstack\x18\x01 \x03(\x0b\x32,.zetasql.ScriptExecutorStateProto.StackFrame\x12\x34\n\x12pending_exceptions\x18\x02 \x03(\x0b\x32\x18.zetasql.ScriptException\x12K\n\x12triggered_features\x18\x03 \x03(\x0e\x32/.zetasql.ScriptExecutorStateProto.ScriptFeature\x12\x10\n\x08timezone\x18\x04 \x01(\t\x12#\n\x1b\x63\x61se_stmt_true_branch_index\x18\x05 \x01(\x03\x12&\n\x1e\x63\x61se_stmt_current_branch_index\x18\x06 \x01(\x03\x12O\n\x11sql_feature_usage\x18\x07 \x01(\x0b\x32\x34.zetasql.ScriptExecutorStateProto.ScriptFeatureUsage\x1a\xc9\x01\n\x13ProcedureDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\tsignature\x18\x02 \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\x12\x1a\n\x12\x61rgument_name_list\x18\x03 \x03(\t\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x12\x16\n\x0eis_dynamic_sql\x18\x05 \x01(\x08\x12.\n\textension\x18\x06 \x01(\x0b\x32\x1b.zetasql.ProcedureExtension\x1a\x88\x04\n\nStackFrame\x12S\n\x14procedure_definition\x18\x01 \x01(\x0b\x32\x35.zetasql.ScriptExecutorStateProto.ProcedureDefinition\x12$\n\tvariables\x18\x02 \x03(\x0b\x32\x11.zetasql.Variable\x12$\n\x1c\x63urrent_location_byte_offset\x18\x03 \x01(\x05\x12\x1e\n\x16\x63ontrol_flow_node_kind\x18\x05 \x01(\x05\x12K\n\nparameters\x18\x04 \x01(\x0b\x32\x37.zetasql.ScriptExecutorStateProto.StackFrame.Parameters\x12,\n\x0e\x66or_loop_stack\x18\x06 \x03(\x0b\x32\x14.google.protobuf.Any\x1a\xbd\x01\n\nParameters\x12S\n\x04mode\x18\x04 \x01(\x0e\x32\x45.zetasql.ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode\x12$\n\tvariables\x18\x05 \x03(\x0b\x32\x11.zetasql.Variable\"4\n\rParameterMode\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05NAMED\x10\x01\x12\x0e\n\nPOSITIONAL\x10\x02\x1aZ\n\x12ScriptFeatureUsage\x12\x11\n\texception\x18\x01 \x01(\x05\x12\x11\n\tcall_stmt\x18\x02 \x01(\x05\x12\x1e\n\x16\x65xecute_immediate_stmt\x18\x03 \x01(\x05\"g\n\rScriptFeature\x12\x0b\n\x07INVALID\x10\x00\x12\x14\n\x10\x45XCEPTION_CAUGHT\x10\x01\x12\x12\n\x0e\x43\x41LL_STATEMENT\x10\x02\x12\x1f\n\x1b\x45XECUTE_IMMEDIATE_STATEMENT\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.scripting.script_executor_state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SCRIPTEXECUTORSTATEPROTO']._serialized_start=233
  _globals['_SCRIPTEXECUTORSTATEPROTO']._serialized_end=1555
  _globals['_SCRIPTEXECUTORSTATEPROTO_PROCEDUREDEFINITION']._serialized_start=634
  _globals['_SCRIPTEXECUTORSTATEPROTO_PROCEDUREDEFINITION']._serialized_end=835
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME']._serialized_start=838
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME']._serialized_end=1358
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME_PARAMETERS']._serialized_start=1169
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME_PARAMETERS']._serialized_end=1358
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME_PARAMETERS_PARAMETERMODE']._serialized_start=1306
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME_PARAMETERS_PARAMETERMODE']._serialized_end=1358
  _globals['_SCRIPTEXECUTORSTATEPROTO_SCRIPTFEATUREUSAGE']._serialized_start=1360
  _globals['_SCRIPTEXECUTORSTATEPROTO_SCRIPTFEATUREUSAGE']._serialized_end=1450
  _globals['_SCRIPTEXECUTORSTATEPROTO_SCRIPTFEATURE']._serialized_start=1452
  _globals['_SCRIPTEXECUTORSTATEPROTO_SCRIPTFEATURE']._serialized_end=1555
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/resolved_ast/serialization.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/resolved_ast/serialization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import annotation_pb2 as zetasql_dot_public_dot_annotation__pb2
from zetasql.wasi._pb2.zetasql.public import parse_location_range_pb2 as zetasql_dot_public_dot_parse__location__range__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2
from zetasql.wasi._pb2.zetasql.public import value_pb2 as zetasql_dot_public_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(zetasql/resolved_ast/serialization.proto\x12\x07zetasql\x1a\x1fzetasql/public/annotation.proto\x1a)zetasql/public/parse_location_range.proto\x1a\x19zetasql/public/type.proto\x1a\x1azetasql/public/value.proto\"\xa1\x01\n\x13ResolvedColumnProto\x12\x11\n\tcolumn_id\x18\x01 \x01(\x03\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04type\x18\x04 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x33\n\x0e\x61nnotation_map\x18\x05 \x01(\x0b\x32\x1b.zetasql.AnnotationMapProto\"Z\n\x12ValueWithTypeProto\x12 \n\x04type\x18\x01 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.zetasql.ValueProto\"J\n\rTableRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10serialization_id\x18\x02 \x01(\x03\x12\x11\n\tfull_name\x18\x03 \x01(\t\"J\n\rModelRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10serialization_id\x18\x02 \x01(\x03\x12\x11\n\tfull_name\x18\x03 \x01(\t\"5\n\x12\x43onnectionRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x03 \x01(\t\"3\n\x10SequenceRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\" \n\x10\x43onstantRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10\x46unctionRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\"+\n\x1bTableValuedFunctionRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\"S\n\x11ResolvedNodeProto\x12>\n\x14parse_location_range\x18\x01 \x01(\x0b\x32 .zetasql.ParseLocationRangeProto\"\\\n\x17\x46ieldDescriptorRefProto\x12\x31\n\x10\x63ontaining_proto\x18\x01 \x01(\x0b\x32\x17.zetasql.ProtoTypeProto\x12\x0e\n\x06number\x18\x02 \x01(\x05\"[\n\x17OneofDescriptorRefProto\x12\x31\n\x10\x63ontaining_proto\x18\x01 \x01(\x0b\x32\x17.zetasql.ProtoTypeProto\x12\r\n\x05index\x18\x02 \x01(\x05\"!\n\x11ProcedureRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\"e\n\x16ResolvedCollationProto\x12\x16\n\x0e\x63ollation_name\x18\x01 \x01(\t\x12\x33\n\nchild_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedCollationProto\"I\n\x0e\x43olumnRefProto\x12)\n\ttable_ref\x18\x01 \x01(\x0b\x32\x16.zetasql.TableRefProto\x12\x0c\n\x04name\x18\x02 \x01(\t\"*\n\x15PropertyGraphRefProto\x12\x11\n\tfull_name\x18\x01 \x01(\t\"h\n GraphPropertyDeclarationRefProto\x12\x36\n\x0eproperty_graph\x18\x01 \x01(\x0b\x32\x1e.zetasql.PropertyGraphRefProto\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x19GraphElementLabelRefProto\x12\x36\n\x0eproperty_graph\x18\x01 \x01(\x0b\x32\x1e.zetasql.PropertyGraphRefProto\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x19GraphElementTableRefProto\x12\x36\n\x0eproperty_graph\x18\x01 \x01(\x0b\x32\x1e.zetasql.PropertyGraphRefProto\x12\x0c\n\x04name\x18\x02 \x01(\tB,\n\x12\x63om.google.zetasqlB\x14ZetaSQLSerializationP\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.resolved_ast.serialization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\024ZetaSQLSerializationP\001'
  _globals['_RESOLVEDCOLUMNPROTO']._serialized_start=185
  _globals['_RESOLVEDCOLUMNPROTO']._serialized_end=346
  _globals['_VALUEWITHTYPEPROTO']._serialized_start=348
  _globals['_VALUEWITHTYPEPROTO']._serialized_end=438
  _globals['_TABLEREFPROTO']._serialized_start=440
  _globals['_TABLEREFPROTO']._serialized_end=514
  _globals['_MODELREFPROTO']._serialized_start=516
  _globals['_MODELREFPROTO']._serialized_end=590
  _globals['_CONNECTIONREFPROTO']._serialized_start=592
  _globals['_CONNECTIONREFPROTO']._serialized_end=645
  _globals['_SEQUENCEREFPROTO']._serialized_start=647
  _globals['_SEQUENCEREFPROTO']._serialized_end=698
  _globals['_CONSTANTREFPROTO']._serialized_start=700
  _globals['_CONSTANTREFPROTO']._serialized_end=732
  _globals['_FUNCTIONREFPROTO']._serialized_start=734
  _globals['_FUNCTIONREFPROTO']._serialized_end=766
  _globals['_TABLEVALUEDFUNCTIONREFPROTO']._serialized_start=768
  _globals['_TABLEVALUEDFUNCTIONREFPROTO']._serialized_end=811
  _globals['_RESOLVEDNODEPROTO']._serialized_start=813
  _globals['_RESOLVEDNODEPROTO']._serialized_end=896
  _globals['_FIELDDESCRIPTORREFPROTO']._serialized_start=898
  _globals['_FIELDDESCRIPTORREFPROTO']._serialized_end=990
  _globals['_ONEOFDESCRIPTORREFPROTO']._serialized_start=992
  _globals['_ONEOFDESCRIPTORREFPROTO']._serialized_end=1083
  _globals['_PROCEDUREREFPROTO']._serialized_start=1085
  _globals['_PROCEDUREREFPROTO']._serialized_end=1118
  _globals['_RESOLVEDCOLLATIONPROTO']._serialized_start=1120
  _globals['_RESOLVEDCOLLATIONPROTO']._serialized_end=1221
  _globals['_COLUMNREFPROTO']._serialized_start=1223
  _globals['_COLUMNREFPROTO']._serialized_end=1296
  _globals['_PROPERTYGRAPHREFPROTO']._serialized_start=1298
  _globals['_PROPERTYGRAPHREFPROTO']._serialized_end=1340
  _globals['_GRAPHPROPERTYDECLARATIONREFPROTO']._serialized_start=1342
  _globals['_GRAPHPROPERTYDECLARATIONREFPROTO']._serialized_end=1446
  _globals['_GRAPHELEMENTLABELREFPROTO']._serialized_start=1448
  _globals['_GRAPHELEMENTLABELREFPROTO']._serialized_end=1545
  _globals['_GRAPHELEMENTTABLEREFPROTO']._serialized_start=1547
  _globals['_GRAPHELEMENTTABLEREFPROTO']._serialized_end=1644
# @@protoc_insertion_point(module_scope)
